@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -22,20 +22,12 @@
 require_once dirname(__FILE__).'/include/config.inc.php';
 require_once dirname(__FILE__).'/include/forms.inc.php';
 
-if (hasRequest('action') && getRequest('action') === 'host.export' && hasRequest('hosts')) {
-	$page['file'] = 'zbx_export_hosts.xml';
-	$page['type'] = detect_page_type(PAGE_TYPE_XML);
-
-	$exportData = true;
-}
-else {
-	$page['title'] = _('Configuration of hosts');
-	$page['file'] = 'hosts.php';
-	$page['type'] = detect_page_type(PAGE_TYPE_HTML);
-	$page['scripts'] = ['multiselect.js'];
-
-	$exportData = false;
-}
+$page['title'] = _('Configuration of hosts');
+$page['file'] = 'hosts.php';
+$page['type'] = detect_page_type(PAGE_TYPE_HTML);
+$page['scripts'] = ['multiselect.js', 'textareaflexible.js', 'class.cviewswitcher.js', 'class.cverticalaccordion.js',
+	'inputsecret.js', 'macrovalue.js', 'class.tab-indicators.js'
+];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -50,7 +42,6 @@ $fields = [
 	'hostids' =>				[T_ZBX_INT, O_OPT, P_SYS,			DB_ID,		null],
 	'groupids' =>				[T_ZBX_INT, O_OPT, P_SYS,			DB_ID,		null],
 	'applications' =>			[T_ZBX_INT, O_OPT, P_SYS,			DB_ID,		null],
-	'groupid' =>				[T_ZBX_INT, O_OPT, P_SYS,			DB_ID,		null],
 	'hostid' =>					[T_ZBX_INT, O_OPT, P_SYS,			DB_ID,		'isset({form}) && {form} == "update"'],
 	'clone_hostid' =>			[T_ZBX_INT, O_OPT, P_SYS,			DB_ID,
 									'isset({form}) && {form} == "full_clone"'
@@ -64,17 +55,22 @@ $fields = [
 	'status' =>					[T_ZBX_INT, O_OPT, null,
 									IN([HOST_STATUS_MONITORED, HOST_STATUS_NOT_MONITORED]), null
 								],
-	'interfaces' =>				[T_ZBX_STR, O_OPT, null,			NOT_EMPTY,
-									'isset({add}) || isset({update})', _('Agent or SNMP or JMX or IPMI interface')
-								],
+	'interfaces' =>				[T_ZBX_STR, O_OPT, null,			null,		null],
 	'mainInterfaces' =>			[T_ZBX_INT, O_OPT, null,			DB_ID,		null],
 	'tags' =>					[T_ZBX_STR, O_OPT, null,			null,		null],
 	'mass_update_tags' =>		[T_ZBX_INT, O_OPT, null,
 									IN([ZBX_ACTION_ADD, ZBX_ACTION_REPLACE, ZBX_ACTION_REMOVE]),
 									null
 								],
+	'mass_update_macros' => 	[T_ZBX_INT, O_OPT, null,
+									IN([ZBX_ACTION_ADD, ZBX_ACTION_REPLACE, ZBX_ACTION_REMOVE, ZBX_ACTION_REMOVE_ALL]),
+									null
+								],
+	'macros_add' =>				[T_ZBX_INT, O_OPT, null, IN([0,1]), null],
+	'macros_update' =>			[T_ZBX_INT, O_OPT, null, IN([0,1]), null],
+	'macros_remove' =>			[T_ZBX_INT, O_OPT, null, IN([0,1]), null],
+	'macros_remove_all' =>		[T_ZBX_INT, O_OPT, null, IN([0,1]), null],
 	'templates' =>				[T_ZBX_INT, O_OPT, null,			DB_ID,		null],
-	'add_template' =>			[T_ZBX_STR, O_OPT, null,			null,		null],
 	'add_templates' =>			[T_ZBX_INT, O_OPT, null,			DB_ID,		null],
 	'templates_rem' =>			[T_ZBX_STR, O_OPT, P_SYS|P_ACT,		null,		null],
 	'clear_templates' =>		[T_ZBX_INT, O_OPT, null,			DB_ID,		null],
@@ -99,8 +95,11 @@ $fields = [
 	'flags' =>					[T_ZBX_INT, O_OPT, null,
 									IN([ZBX_FLAG_DISCOVERY_NORMAL, ZBX_FLAG_DISCOVERY_CREATED]), null
 								],
-	'mass_replace_tpls' =>		[T_ZBX_STR, O_OPT, null,			null,		null],
 	'mass_clear_tpls' =>		[T_ZBX_STR, O_OPT, null,			null,		null],
+	'mass_action_tpls' =>		[T_ZBX_INT, O_OPT, null,
+									IN([ZBX_ACTION_ADD, ZBX_ACTION_REPLACE, ZBX_ACTION_REMOVE]),
+									null
+								],
 	'inventory_mode' =>			[T_ZBX_INT, O_OPT, null,
 									IN(HOST_INVENTORY_DISABLED.','.HOST_INVENTORY_MANUAL.','.HOST_INVENTORY_AUTOMATIC),
 									null
@@ -134,6 +133,7 @@ $fields = [
 	'filter_rst' =>				[T_ZBX_STR, O_OPT, P_SYS,			null,		null],
 	'filter_host' =>			[T_ZBX_STR, O_OPT, null,			null,		null],
 	'filter_templates' =>		[T_ZBX_INT, O_OPT, null,			DB_ID,		null],
+	'filter_groups' =>			[T_ZBX_INT, O_OPT, null,			DB_ID,		null],
 	'filter_ip' =>				[T_ZBX_STR, O_OPT, null,			null,		null],
 	'filter_dns' =>				[T_ZBX_STR, O_OPT, null,			null,		null],
 	'filter_port' =>			[T_ZBX_STR, O_OPT, null,			null,		null],
@@ -156,9 +156,6 @@ check_fields($fields);
 /*
  * Permissions
  */
-if (getRequest('groupid') && !isWritableHostGroups([getRequest('groupid')])) {
-	access_deny();
-}
 if (getRequest('hostid')) {
 	$hosts = API::Host()->get([
 		'output' => [],
@@ -171,27 +168,6 @@ if (getRequest('hostid')) {
 	}
 }
 
-$hostIds = getRequest('hosts', []);
-
-/*
- * Export
- */
-if ($exportData) {
-	$export = new CConfigurationExport(['hosts' => $hostIds]);
-	$export->setBuilder(new CConfigurationExportBuilder());
-	$export->setWriter(CExportWriterFactory::getWriter(CExportWriterFactory::XML));
-	$exportData = $export->export();
-
-	if (hasErrorMesssages()) {
-		show_messages();
-	}
-	else {
-		print($exportData);
-	}
-
-	exit;
-}
-
 /*
  * Filter
  */
@@ -204,6 +180,7 @@ if (hasRequest('filter_set')) {
 		PROFILE_TYPE_INT
 	);
 	CProfile::updateArray('web.hosts.filter_templates', getRequest('filter_templates', []), PROFILE_TYPE_ID);
+	CProfile::updateArray('web.hosts.filter_groups', getRequest('filter_groups', []), PROFILE_TYPE_ID);
 	CProfile::updateArray('web.hosts.filter_proxyids', getRequest('filter_proxyids', []), PROFILE_TYPE_ID);
 	CProfile::update('web.hosts.filter.evaltype', getRequest('filter_evaltype', TAG_EVAL_TYPE_AND_OR),
 		PROFILE_TYPE_INT
@@ -231,6 +208,7 @@ elseif (hasRequest('filter_rst')) {
 	CProfile::delete('web.hosts.filter_port');
 	CProfile::delete('web.hosts.filter_monitored_by');
 	CProfile::deleteIdx('web.hosts.filter_templates');
+	CProfile::deleteIdx('web.hosts.filter_groups');
 	CProfile::deleteIdx('web.hosts.filter_proxyids');
 	CProfile::delete('web.hosts.filter.evaltype');
 	CProfile::deleteIdx('web.hosts.filter.tags.tag');
@@ -244,6 +222,7 @@ $filter = [
 	'dns' => CProfile::get('web.hosts.filter_dns', ''),
 	'host' => CProfile::get('web.hosts.filter_host', ''),
 	'templates' => CProfile::getArray('web.hosts.filter_templates', []),
+	'groups' => CProfile::getArray('web.hosts.filter_groups', []),
 	'port' => CProfile::get('web.hosts.filter_port', ''),
 	'monitored_by' => CProfile::get('web.hosts.filter_monitored_by', ZBX_MONITORED_BY_ANY),
 	'proxyids' => CProfile::getArray('web.hosts.filter_proxyids', []),
@@ -258,6 +237,7 @@ foreach (CProfile::getArray('web.hosts.filter.tags.tag', []) as $i => $tag) {
 		'operator' => CProfile::get('web.hosts.filter.tags.operator', null, $i)
 	];
 }
+CArrayHelper::sort($filter['tags'], ['tag', 'value', 'operator']);
 
 $tags = getRequest('tags', []);
 foreach ($tags as $key => $tag) {
@@ -276,23 +256,19 @@ foreach ($tags as $key => $tag) {
 	}
 }
 
-// remove inherited macros data (actions: 'add', 'update' and 'form')
+// Remove inherited macros data (actions: 'add', 'update' and 'form').
 $macros = cleanInheritedMacros(getRequest('macros', []));
 
-// remove empty new macro lines
-foreach ($macros as $idx => $macro) {
-	if (!array_key_exists('hostmacroid', $macro) && $macro['macro'] === '' && $macro['value'] === '') {
-		unset($macros[$idx]);
-	}
-}
+// Remove empty new macro lines.
+$macros = array_filter($macros, function($macro) {
+	$keys = array_flip(['hostmacroid', 'macro', 'value', 'description']);
+
+	return (bool) array_filter(array_intersect_key($macro, $keys));
+});
 
 /*
  * Actions
  */
-if (hasRequest('add_template') && hasRequest('add_templates')) {
-	$_REQUEST['templates'] = getRequest('templates', []);
-	$_REQUEST['templates'] = array_merge($_REQUEST['templates'], $_REQUEST['add_templates']);
-}
 if (hasRequest('unlink') || hasRequest('unlink_and_clear')) {
 	$_REQUEST['clear_templates'] = getRequest('clear_templates', []);
 
@@ -351,7 +327,7 @@ elseif (hasRequest('hostid') && (hasRequest('clone') || hasRequest('full_clone')
 		$interfaceid = 1;
 		foreach ($_REQUEST['interfaces'] as &$interface) {
 			$interface['interfaceid'] = (string) $interfaceid++;
-			unset($interface['locked'], $interface['items']);
+			unset($interface['items']);
 		}
 		unset($interface);
 	}
@@ -360,6 +336,23 @@ elseif (hasRequest('hostid') && (hasRequest('clone') || hasRequest('full_clone')
 		$_REQUEST['clone_hostid'] = $_REQUEST['hostid'];
 	}
 
+	if ($macros && in_array(ZBX_MACRO_TYPE_SECRET, array_column($macros, 'type'))) {
+		// Reset macro type and value.
+		$macros = array_map(function($value) {
+			return ($value['type'] == ZBX_MACRO_TYPE_SECRET)
+				? ['value' => '', 'type' => ZBX_MACRO_TYPE_TEXT] + $value
+				: $value;
+		}, $macros);
+
+		$msg = [
+			'type' => 'error',
+			'message' => _('The cloned host contains user defined macros with type "Secret text". The value and type of these macros were reset.'),
+			'source' => ''
+		];
+
+		echo makeMessageBox(false, [$msg], null, true, false)->addClass(ZBX_STYLE_MSG_WARNING);
+	}
+
 	unset($_REQUEST['hostid'], $_REQUEST['flags']);
 }
 elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && hasRequest('masssave')) {
@@ -373,8 +366,7 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 
 		// filter only normal and discovery created hosts
 		$options = [
-			'output' => ['hostid'],
-			'selectInventory' => ['inventory_mode'],
+			'output' => ['hostid', 'inventory_mode'],
 			'hostids' => $hostids,
 			'filter' => ['flags' => [ZBX_FLAG_DISCOVERY_NORMAL, ZBX_FLAG_DISCOVERY_CREATED]]
 		];
@@ -383,7 +375,8 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 			$options['selectGroups'] = ['groupid'];
 		}
 
-		if (array_key_exists('templates', $visible) && !hasRequest('mass_replace_tpls')) {
+		if (array_key_exists('templates', $visible)
+				&& !(getRequest('mass_action_tpls') == ZBX_ACTION_REPLACE && !hasRequest('mass_clear_tpls'))) {
 			$options['selectParentTemplates'] = ['templateid'];
 		}
 
@@ -403,6 +396,15 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 			$tags = array_values($unique_tags);
 		}
 
+		if (array_key_exists('macros', $visible)) {
+			$mass_update_macros = getRequest('mass_update_macros', ZBX_ACTION_ADD);
+
+			if ($mass_update_macros == ZBX_ACTION_ADD || $mass_update_macros == ZBX_ACTION_REPLACE
+					|| $mass_update_macros == ZBX_ACTION_REMOVE) {
+				$options['selectMacros'] = ['hostmacroid', 'macro'];
+			}
+		}
+
 		$hosts = API::Host()->get($options);
 
 		if (array_key_exists('groups', $visible)) {
@@ -455,27 +457,6 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 			$new_values['status'] = getRequest('status', HOST_STATUS_NOT_MONITORED);
 		}
 
-		$templateids = [];
-		if (array_key_exists('templates', $visible)) {
-			$templateids = $_REQUEST['templates'];
-
-			if (hasRequest('mass_replace_tpls')) {
-				if (hasRequest('mass_clear_tpls')) {
-					$host_templates = API::Template()->get([
-						'output' => ['templateid'],
-						'hostids' => $hostids
-					]);
-
-					$host_templateids = zbx_objectValues($host_templates, 'templateid');
-					$templates_to_delete = array_diff($host_templateids, $templateids);
-
-					$new_values['templates_clear'] = zbx_toObject($templates_to_delete, 'templateid');
-				}
-
-				$new_values['templates'] = $templateids;
-			}
-		}
-
 		$host_inventory = array_intersect_key(getRequest('host_inventory', []), $visible);
 
 		if (array_key_exists('inventory_mode', $visible)) {
@@ -503,6 +484,9 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 			}
 		}
 
+		$host_macros_add = [];
+		$host_macros_update = [];
+		$host_macros_remove = [];
 		foreach ($hosts as &$host) {
 			if (array_key_exists('groups', $visible)) {
 				if ($new_groupids && $mass_update_groups == ZBX_ACTION_ADD) {
@@ -520,17 +504,38 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 				}
 			}
 
-			if ($templateids && array_key_exists('parentTemplates', $host)) {
-				$host['templates'] = array_unique(
-					array_merge($templateids, zbx_objectValues($host['parentTemplates'], 'templateid'))
-				);
+			if (array_key_exists('templates', $visible)) {
+				$host_templateids = array_key_exists('parentTemplates', $host)
+					? zbx_objectValues($host['parentTemplates'], 'templateid')
+					: [];
+
+				switch (getRequest('mass_action_tpls')) {
+					case ZBX_ACTION_ADD:
+						$host['templates'] = array_unique(array_merge($host_templateids, getRequest('templates', [])));
+						break;
+
+					case ZBX_ACTION_REPLACE:
+						$host['templates'] = getRequest('templates', []);
+						if (getRequest('mass_clear_tpls')) {
+							$host['templates_clear'] = array_unique(
+								array_diff($host_templateids, getRequest('templates', []))
+							);
+						}
+						break;
+
+					case ZBX_ACTION_REMOVE:
+						$host['templates'] = array_unique(array_diff($host_templateids, getRequest('templates', [])));
+						if (getRequest('mass_clear_tpls')) {
+							$host['templates_clear'] = array_unique(getRequest('templates', []));
+						}
+						break;
+				}
 			}
 
 			if (array_key_exists('inventory_mode', $new_values)) {
 				$host['inventory'] = $host_inventory;
 			}
-			elseif (array_key_exists('inventory_mode', $host['inventory'])
-					&& $host['inventory']['inventory_mode'] != HOST_INVENTORY_DISABLED) {
+			elseif ($host['inventory_mode'] != HOST_INVENTORY_DISABLED) {
 				$host['inventory'] = $host_inventory;
 			}
 			else {
@@ -567,6 +572,81 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 				}
 			}
 
+			if (array_key_exists('macros', $visible)) {
+				switch ($mass_update_macros) {
+					case ZBX_ACTION_ADD:
+						if ($macros) {
+							$update_existing = getRequest('macros_add', 0);
+
+							foreach ($macros as $macro) {
+								foreach ($host['macros'] as $host_macro) {
+									if ($macro['macro'] === $host_macro['macro']) {
+										if ($update_existing) {
+											$macro['hostmacroid'] = $host_macro['hostmacroid'];
+											$host_macros_update[] = $macro;
+										}
+
+										continue 2;
+									}
+								}
+
+								$macro['hostid'] = $host['hostid'];
+								$host_macros_add[] = $macro;
+							}
+						}
+						break;
+
+					case ZBX_ACTION_REPLACE: // In Macros its update.
+						if ($macros) {
+							$add_missing = getRequest('macros_update', 0);
+
+							foreach ($macros as $macro) {
+								foreach ($host['macros'] as $host_macro) {
+									if ($macro['macro'] === $host_macro['macro']) {
+										$macro['hostmacroid'] = $host_macro['hostmacroid'];
+										$host_macros_update[] = $macro;
+
+										continue 2;
+									}
+								}
+
+								if ($add_missing) {
+									$macro['hostid'] = $host['hostid'];
+									$host_macros_add[] = $macro;
+								}
+							}
+						}
+						break;
+
+					case ZBX_ACTION_REMOVE:
+						if ($macros) {
+							$except_selected = getRequest('macros_remove', 0);
+
+							$macro_names = array_column($macros, 'macro');
+
+							foreach ($host['macros'] as $host_macro) {
+								if ((!$except_selected && in_array($host_macro['macro'], $macro_names))
+										|| ($except_selected && !in_array($host_macro['macro'], $macro_names))) {
+									$host_macros_remove[] = $host_macro['hostmacroid'];
+								}
+							}
+						}
+						break;
+
+					case ZBX_ACTION_REMOVE_ALL:
+						if (!getRequest('macros_remove_all', 0)) {
+							throw new Exception();
+						}
+
+						$host['macros'] = [];
+						break;
+				}
+
+				if ($mass_update_macros != ZBX_ACTION_REMOVE_ALL) {
+					unset($host['macros']);
+				}
+			}
+
 			unset($host['parentTemplates']);
 
 			$host = $new_values + $host;
@@ -577,6 +657,28 @@ elseif (hasRequest('action') && getRequest('action') === 'host.massupdate' && ha
 			throw new Exception();
 		}
 
+		/**
+		 * Macros must be updated separately, since calling API::UserMacro->replaceMacros() inside
+		 * API::Host->update() results in loss of secret macro values.
+		 */
+		if ($host_macros_remove) {
+			if (!API::UserMacro()->delete($host_macros_remove)) {
+				throw new Exception();
+			}
+		}
+
+		if ($host_macros_add) {
+			if (!API::UserMacro()->create($host_macros_add)) {
+				throw new Exception();
+			}
+		}
+
+		if ($host_macros_update) {
+			if (!API::UserMacro()->update($host_macros_update)) {
+				throw new Exception();
+			}
+		}
+
 		DBend(true);
 
 		uncheckTableRows();
@@ -630,27 +732,26 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			];
 		}
 		else {
-			// templates
+			// Linked templates.
 			$templates = [];
 
-			foreach (getRequest('templates', []) as $templateId) {
-				$templates[] = ['templateid' => $templateId];
+			foreach (array_merge(getRequest('templates', []), getRequest('add_templates', [])) as $templateid) {
+				$templates[] = ['templateid' => $templateid];
 			}
 
 			// interfaces
 			$interfaces = getRequest('interfaces', []);
 
 			foreach ($interfaces as $key => $interface) {
-				if (zbx_empty($interface['ip']) && zbx_empty($interface['dns'])) {
-					unset($interface[$key]);
-					continue;
-				}
+				// Process SNMP interface fields.
+				if ($interface['type'] == INTERFACE_TYPE_SNMP) {
+					if (!array_key_exists('details', $interface)) {
+						$interface['details'] = [];
+					}
 
-				if ($interface['type'] == INTERFACE_TYPE_SNMP && !isset($interface['bulk'])) {
-					$interfaces[$key]['bulk'] = SNMP_BULK_DISABLED;
-				}
-				else {
-					$interfaces[$key]['bulk'] = SNMP_BULK_ENABLED;
+					$interfaces[$key]['details']['bulk'] = array_key_exists('bulk', $interface['details'])
+						? SNMP_BULK_ENABLED
+						: SNMP_BULK_DISABLED;
 				}
 
 				if ($interface['isNew']) {
@@ -663,7 +764,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 			$mainInterfaces = getRequest('mainInterfaces', []);
 			foreach ([INTERFACE_TYPE_AGENT, INTERFACE_TYPE_SNMP, INTERFACE_TYPE_JMX, INTERFACE_TYPE_IPMI] as $type) {
-				if (array_key_exists($type, $mainInterfaces)) {
+				if (array_key_exists($type, $mainInterfaces) && array_key_exists($mainInterfaces[$type], $interfaces)) {
 					$interfaces[$mainInterfaces[$type]]['main'] = INTERFACE_PRIMARY;
 				}
 			}
@@ -738,8 +839,6 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			else {
 				throw new Exception();
 			}
-
-			add_audit_ext(AUDIT_ACTION_ADD, AUDIT_RESOURCE_HOST, $hostId, $host['host'], null, null, null);
 		}
 		else {
 			$host['hostid'] = $hostId;
@@ -747,16 +846,6 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			if (!API::Host()->update($host)) {
 				throw new Exception();
 			}
-
-			$dbHostNew = API::Host()->get([
-				'output' => API_OUTPUT_EXTEND,
-				'hostids' => $hostId,
-				'editable' => true
-			]);
-			$dbHostNew = reset($dbHostNew);
-
-			add_audit_ext(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_HOST, $dbHostNew['hostid'], $dbHostNew['host'], 'hosts',
-				$dbHost, $dbHostNew);
 		}
 
 		// full clone
@@ -892,13 +981,14 @@ elseif (hasRequest('hosts') && hasRequest('action') && str_in_array(getRequest('
 		'templated_hosts' => true,
 		'output' => ['hostid']
 	]);
-	$actHosts = zbx_objectValues($actHosts, 'hostid');
 
 	if ($actHosts) {
-		DBstart();
+		foreach ($actHosts as &$host) {
+			$host['status'] = $status;
+		}
+		unset($host);
 
-		$result = updateHostStatus($actHosts, $status);
-		$result = DBend($result);
+		$result = (bool) API::Host()->update($actHosts);
 
 		if ($result) {
 			uncheckTableRows();
@@ -920,27 +1010,24 @@ elseif (hasRequest('hosts') && hasRequest('action') && str_in_array(getRequest('
 /*
  * Display
  */
-$pageFilter = new CPageFilter([
-	'groups' => [
-		'real_hosts' => true,
-		'editable' => true
-	],
-	'groupid' => getRequest('groupid')
-]);
-
-$_REQUEST['groupid'] = $pageFilter->groupid;
-$_REQUEST['hostid'] = getRequest('hostid', 0);
-
-$config = select_config();
-
 if (hasRequest('hosts') && (getRequest('action') === 'host.massupdateform' || hasRequest('masssave'))) {
 	$data = [
 		'hosts' => getRequest('hosts'),
 		'visible' => getRequest('visible', []),
-		'mass_replace_tpls' => getRequest('mass_replace_tpls'),
+		'mass_action_tpls' => getRequest('mass_action_tpls'),
 		'mass_clear_tpls' => getRequest('mass_clear_tpls'),
 		'groups' => getRequest('groups', []),
+		'mass_update_groups' => getRequest('mass_update_groups', ZBX_ACTION_ADD),
 		'tags' => $tags,
+		'mass_update_tags' => getRequest('mass_update_tags', ZBX_ACTION_ADD),
+		'macros' => $macros,
+		'macros_checkbox' => [
+			ZBX_ACTION_ADD => getRequest('macros_add', '0'),
+			ZBX_ACTION_REPLACE => getRequest('macros_update', '0'),
+			ZBX_ACTION_REMOVE => getRequest('macros_remove', '0'),
+			ZBX_ACTION_REMOVE_ALL => getRequest('macros_remove_all', '0')
+		],
+		'macros_visible' => getRequest('mass_update_macros', ZBX_ACTION_ADD),
 		'status' => getRequest('status', HOST_STATUS_MONITORED),
 		'description' => getRequest('description'),
 		'proxy_hostid' => getRequest('proxy_hostid', ''),
@@ -983,6 +1070,10 @@ if (hasRequest('hosts') && (getRequest('action') === 'host.massupdateform' || ha
 		]), ['templateid' => 'id'])
 		: [];
 
+	if (!$data['macros']) {
+		$data['macros'] = [['macro' => '', 'type' => ZBX_MACRO_TYPE_TEXT, 'value' => '', 'description' => '']];
+	}
+
 	$hostView = new CView('configuration.host.massupdate', $data);
 }
 elseif (hasRequest('form')) {
@@ -1004,6 +1095,7 @@ elseif (hasRequest('form')) {
 
 		// Templates
 		'templates' => getRequest('templates', []),
+		'add_templates' => [],
 		'clear_templates' => getRequest('clear_templates', []),
 		'original_templates' => [],
 		'linked_templates' => [],
@@ -1023,7 +1115,7 @@ elseif (hasRequest('form')) {
 		'show_inherited_macros' => getRequest('show_inherited_macros', 0),
 
 		// Host inventory
-		'inventory_mode' => getRequest('inventory_mode', $config['default_inventory_mode']),
+		'inventory_mode' => getRequest('inventory_mode', CSettingsHelper::get(CSettingsHelper::DEFAULT_INVENTORY_MODE)),
 		'host_inventory' => getRequest('host_inventory', []),
 		'inventory_items' => [],
 
@@ -1036,20 +1128,19 @@ elseif (hasRequest('form')) {
 		'tls_psk' => getRequest('tls_psk', '')
 	];
 
-	$groups = [];
-
 	if (!hasRequest('form_refresh')) {
 		if ($data['hostid'] != 0) {
 			$dbHosts = API::Host()->get([
 				'output' => ['hostid', 'proxy_hostid', 'host', 'name', 'status', 'ipmi_authtype', 'ipmi_privilege',
 					'ipmi_username', 'ipmi_password', 'flags', 'description', 'tls_connect', 'tls_accept', 'tls_issuer',
-					'tls_subject', 'tls_psk_identity', 'tls_psk'
+					'tls_subject', 'tls_psk_identity', 'tls_psk', 'inventory_mode'
 				],
 				'selectGroups' => ['groupid'],
 				'selectParentTemplates' => ['templateid'],
-				'selectMacros' => ['hostmacroid', 'macro', 'value'],
+				'selectMacros' => ['hostmacroid', 'macro', 'value', 'description', 'type'],
 				'selectDiscoveryRule' => ['itemid', 'name'],
-				'selectInventory' => true,
+				'selectHostDiscovery' => ['parent_hostid'],
+				'selectInventory' => API_OUTPUT_EXTEND,
 				'selectTags' => ['tag', 'value'],
 				'hostids' => [$data['hostid']]
 			]);
@@ -1058,14 +1149,15 @@ elseif (hasRequest('form')) {
 			$data['flags'] = $dbHost['flags'];
 			if ($data['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
 				$data['discoveryRule'] = $dbHost['discoveryRule'];
+				$data['hostDiscovery'] = $dbHost['hostDiscovery'];
 			}
 
 			// Host
 			$data['host'] = $dbHost['host'];
 			$data['visiblename'] = $dbHost['name'];
 			$data['interfaces'] = API::HostInterface()->get([
-				'output' => ['interfaceid', 'main', 'type', 'useip', 'ip', 'dns', 'port', 'bulk'],
-				'selectItems' => ['type'],
+				'output' => API_OUTPUT_EXTEND,
+				'selectItems' => ['itemid'],
 				'hostids' => [$data['hostid']],
 				'sortfield' => 'interfaceid'
 			]);
@@ -1091,31 +1183,13 @@ elseif (hasRequest('form')) {
 
 			// Interfaces
 			foreach ($data['interfaces'] as &$interface) {
-				if ($data['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
-					$interface['locked'] = true;
-				}
-				else {
-					// check if interface has items that require specific interface type, if so type cannot be changed
-					$interface['locked'] = false;
-					foreach ($interface['items'] as $item) {
-						$type = itemTypeInterface($item['type']);
-						if ($type !== false && $type != INTERFACE_TYPE_ANY) {
-							$interface['locked'] = true;
-							break;
-						}
-					}
-				}
-
 				$interface['items'] = (bool) $interface['items'];
 			}
 			unset($interface);
 
 			// Host inventory
-			$data['inventory_mode'] = array_key_exists('inventory_mode', $dbHost['inventory'])
-				? $dbHost['inventory']['inventory_mode']
-				: HOST_INVENTORY_DISABLED;
+			$data['inventory_mode'] = $dbHost['inventory_mode'];
 			$data['host_inventory'] = $dbHost['inventory'];
-			unset($data['host_inventory']['inventory_mode']);
 
 			// Encryption
 			$data['tls_connect'] = $dbHost['tls_connect'];
@@ -1133,9 +1207,7 @@ elseif (hasRequest('form')) {
 			$groups = zbx_objectValues($dbHost['groups'], 'groupid');
 		}
 		else {
-			if (getRequest('groupid', 0) != 0) {
-				$groups[] = getRequest('groupid');
-			}
+			$groups = getRequest('groupids', []);
 
 			$data['status'] = HOST_STATUS_MONITORED;
 		}
@@ -1146,6 +1218,7 @@ elseif (hasRequest('form')) {
 				'output' => ['flags'],
 				'selectParentTemplates' => ['templateid'],
 				'selectDiscoveryRule' => ['itemid', 'name'],
+				'selectHostDiscovery' => ['parent_hostid'],
 				'hostids' => [$data['hostid']]
 			]);
 			$dbHost = reset($dbHosts);
@@ -1153,6 +1226,7 @@ elseif (hasRequest('form')) {
 			$data['flags'] = $dbHost['flags'];
 			if ($data['flags'] == ZBX_FLAG_DISCOVERY_CREATED) {
 				$data['discoveryRule'] = $dbHost['discoveryRule'];
+				$data['hostDiscovery'] = $dbHost['hostDiscovery'];
 			}
 
 			$templateids = zbx_objectValues($dbHost['parentTemplates'], 'templateid');
@@ -1170,6 +1244,8 @@ elseif (hasRequest('form')) {
 		$groups = getRequest('groups', []);
 	}
 
+	$data['readonly'] = ($data['flags'] == ZBX_FLAG_DISCOVERY_CREATED);
+
 	if ($data['hostid'] != 0) {
 		// get items that populate host inventory fields
 		$data['inventory_items'] = API::Item()->get([
@@ -1214,17 +1290,23 @@ elseif (hasRequest('form')) {
 		CArrayHelper::sort($data['tags'], ['tag', 'value']);
 	}
 
-	// macros
+	// Add inherited macros to host macros.
 	if ($data['show_inherited_macros']) {
-		$data['macros'] = mergeInheritedMacros($data['macros'], getInheritedMacros($data['templates']));
+		$data['macros'] = mergeInheritedMacros($data['macros'], getInheritedMacros(
+			array_merge($data['templates'], getRequest('add_templates', []))
+		));
 	}
+
+	// Sort only after inherited macros are added. Otherwise the list will look chaotic.
 	$data['macros'] = array_values(order_macros($data['macros'], 'macro'));
 
-	if (!$data['macros'] && $data['flags'] != ZBX_FLAG_DISCOVERY_CREATED) {
-		$macro = ['macro' => '', 'value' => ''];
+	if (!$data['macros'] && !$data['readonly']) {
+		$macro = ['macro' => '', 'value' => '', 'description' => '', 'type' => ZBX_MACRO_TYPE_TEXT];
+
 		if ($data['show_inherited_macros']) {
-			$macro['type'] = ZBX_PROPERTY_OWN;
+			$macro['inherited_type'] = ZBX_PROPERTY_OWN;
 		}
+
 		$data['macros'][] = $macro;
 	}
 
@@ -1278,21 +1360,44 @@ elseif (hasRequest('form')) {
 	}
 	CArrayHelper::sort($data['groups_ms'], ['name']);
 
-	if ($data['templates']) {
-		$data['linked_templates'] = API::Template()->get([
-			'output' => ['templateid', 'name'],
-			'templateids' => $data['templates']
-		]);
-		CArrayHelper::sort($data['linked_templates'], ['name']);
+	// Add already linked and new templates.
+	$request_add_templates = getRequest('add_templates', []);
 
-		$data['writable_templates'] = API::Template()->get([
-			'output' => ['templateid'],
-			'templateids' => $data['templates'],
-			'editable' => true,
+	if ($data['templates'] || $request_add_templates) {
+		$templates = API::Template()->get([
+			'output' => ['templateid', 'name'],
+			'templateids' => array_merge($data['templates'], $request_add_templates),
 			'preservekeys' => true
 		]);
+
+		$data['linked_templates'] = array_intersect_key($templates, array_flip($data['templates']));
+		CArrayHelper::sort($data['linked_templates'], ['name']);
+
+		$data['add_templates'] = array_intersect_key($templates, array_flip($request_add_templates));
+
+		foreach ($data['add_templates'] as &$template) {
+			$template = CArrayHelper::renameKeys($template, ['templateid' => 'id']);
+		}
+		unset($template);
+
+		if ($data['templates']) {
+			$data['writable_templates'] = API::Template()->get([
+				'output' => ['templateid'],
+				'templateids' => $data['templates'],
+				'editable' => true,
+				'preservekeys' => true
+			]);
+		}
 	}
 
+	// This data is used in common.template.edit.js.php.
+	$data['macros_tab'] = [
+		'linked_templates' => array_map('strval', array_keys($data['linked_templates'])),
+		'add_templates' => array_map('strval', array_keys($data['add_templates']))
+	];
+
+	$data['allowed_ui_conf_templates'] = CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES);
+
 	$hostView = new CView('configuration.host.edit', $data);
 }
 else {
@@ -1302,6 +1407,22 @@ else {
 	CProfile::update('web.'.$page['file'].'.sort', $sortField, PROFILE_TYPE_STR);
 	CProfile::update('web.'.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR);
 
+	// Get host groups.
+	$filter['groups'] = $filter['groups']
+		? CArrayHelper::renameObjectsKeys(API::HostGroup()->get([
+			'output' => ['groupid', 'name'],
+			'groupids' => $filter['groups'],
+			'editable' => true,
+			'preservekeys' => true
+		]), ['groupid' => 'id'])
+		: [];
+
+	$filter_groupids = $filter['groups'] ? array_keys($filter['groups']) : null;
+	if ($filter_groupids) {
+		$filter_groupids = getSubGroups($filter_groupids);
+	}
+
+	// Get templates.
 	$filter['templates'] = $filter['templates']
 		? CArrayHelper::renameObjectsKeys(API::Template()->get([
 			'output' => ['templateid', 'name'],
@@ -1310,54 +1431,63 @@ else {
 		]), ['templateid' => 'id'])
 		: [];
 
-	// get Hosts
-	$hosts = [];
-	if ($pageFilter->groupsSelected) {
-		switch ($filter['monitored_by']) {
-			case ZBX_MONITORED_BY_ANY:
-				$proxyids = null;
-				break;
+	switch ($filter['monitored_by']) {
+		case ZBX_MONITORED_BY_ANY:
+			$proxyids = null;
+			break;
 
-			case ZBX_MONITORED_BY_PROXY:
-				$proxyids = $filter['proxyids']
-					? $filter['proxyids']
-					: array_keys(API::Proxy()->get([
-						'output' => [],
-						'preservekeys' => true
-					]));
-				break;
+		case ZBX_MONITORED_BY_PROXY:
+			$proxyids = $filter['proxyids']
+				? $filter['proxyids']
+				: array_keys(API::Proxy()->get([
+					'output' => [],
+					'preservekeys' => true
+				]));
+			break;
 
-			case ZBX_MONITORED_BY_SERVER:
-				$proxyids = 0;
-				break;
-		}
-
-		$hosts = API::Host()->get([
-			'output' => ['hostid', $sortField],
-			'evaltype' => $filter['evaltype'],
-			'tags' => $filter['tags'],
-			'groupids' => $pageFilter->groupids,
-			'templateids' => $filter['templates'] ? array_keys($filter['templates']) : null,
-			'editable' => true,
-			'sortfield' => $sortField,
-			'limit' => $config['search_limit'] + 1,
-			'search' => [
-				'name' => ($filter['host'] === '') ? null : $filter['host'],
-				'ip' => ($filter['ip'] === '') ? null : $filter['ip'],
-				'dns' => ($filter['dns'] === '') ? null : $filter['dns']
-			],
-			'filter' => [
-				'port' => ($filter['port'] === '') ? null : $filter['port']
-			],
-			'proxyids' => $proxyids
-		]);
+		case ZBX_MONITORED_BY_SERVER:
+			$proxyids = 0;
+			break;
 	}
+
+	// Select hosts.
+	$limit = CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1;
+	$hosts = API::Host()->get([
+		'output' => ['hostid', $sortField],
+		'evaltype' => $filter['evaltype'],
+		'tags' => $filter['tags'],
+		'groupids' => $filter_groupids,
+		'templateids' => $filter['templates'] ? array_keys($filter['templates']) : null,
+		'editable' => true,
+		'sortfield' => $sortField,
+		'limit' => $limit,
+		'search' => [
+			'name' => ($filter['host'] === '') ? null : $filter['host'],
+			'ip' => ($filter['ip'] === '') ? null : $filter['ip'],
+			'dns' => ($filter['dns'] === '') ? null : $filter['dns']
+		],
+		'filter' => [
+			'port' => ($filter['port'] === '') ? null : $filter['port']
+		],
+		'proxyids' => $proxyids
+	]);
+
 	order_result($hosts, $sortField, $sortOrder);
 
-	$url = (new CUrl('hosts.php'))
-		->setArgument('groupid', $pageFilter->groupid);
+	// pager
+	if (hasRequest('page')) {
+		$page_num = getRequest('page');
+	}
+	elseif (isRequestMethod('get') && !hasRequest('cancel')) {
+		$page_num = 1;
+	}
+	else {
+		$page_num = CPagerHelper::loadPage($page['file']);
+	}
 
-	$pagingLine = getPagingLine($hosts, $sortOrder, $url);
+	CPagerHelper::savePage($page['file'], $page_num);
+
+	$pagingLine = CPagerHelper::paginate($page_num, $hosts, $sortOrder, new CUrl('hosts.php'));
 
 	$hosts = API::Host()->get([
 		'output' => API_OUTPUT_EXTEND,
@@ -1459,14 +1589,12 @@ else {
 	}
 
 	$data = [
-		'pageFilter' => $pageFilter,
 		'hosts' => $hosts,
 		'paging' => $pagingLine,
+		'page' => $page_num,
 		'filter' => $filter,
 		'sortField' => $sortField,
 		'sortOrder' => $sortOrder,
-		'groupId' => $pageFilter->groupid,
-		'config' => $config,
 		'templates' => $templates,
 		'maintenances' => $db_maintenances,
 		'writable_templates' => $writable_templates,
@@ -1474,13 +1602,16 @@ else {
 		'proxies_ms' => $proxies_ms,
 		'profileIdx' => 'web.hosts.filter',
 		'active_tab' => CProfile::get('web.hosts.filter.active', 1),
-		'tags' => makeTags($hosts, true, 'hostid', ZBX_TAG_COUNT_DEFAULT, $filter['tags'])
+		'tags' => makeTags($hosts, true, 'hostid', ZBX_TAG_COUNT_DEFAULT, $filter['tags']),
+		'config' => [
+			'max_in_table' => CSettingsHelper::get(CSettingsHelper::MAX_IN_TABLE)
+		],
+		'allowed_ui_conf_templates' => CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES)
 	];
 
 	$hostView = new CView('configuration.host.list', $data);
 }
 
-$hostView->render();
-$hostView->show();
+echo $hostView->getOutput();
 
 require_once dirname(__FILE__).'/include/page_footer.php';
