@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,6 +24,13 @@
  */
 class CImage extends CApiService {
 
+	public const ACCESS_RULES = [
+		'get' => ['min_user_type' => USER_TYPE_ZABBIX_USER],
+		'create' => ['min_user_type' => USER_TYPE_SUPER_ADMIN],
+		'update' => ['min_user_type' => USER_TYPE_SUPER_ADMIN],
+		'delete' => ['min_user_type' => USER_TYPE_SUPER_ADMIN]
+	];
+
 	protected $tableName = 'images';
 	protected $tableAlias = 'i';
 	protected $sortColumns = ['imageid', 'name'];
@@ -31,18 +38,24 @@ class CImage extends CApiService {
 	/**
 	 * Get images data
 	 *
-	 * @param array $options
-	 * @param array $options['itemids']
-	 * @param array $options['hostids']
-	 * @param array $options['groupids']
-	 * @param array $options['triggerids']
-	 * @param array $options['imageids']
-	 * @param boolean $options['status']
-	 * @param boolean $options['editable']
-	 * @param boolean $options['count']
-	 * @param string $options['pattern']
-	 * @param int $options['limit']
-	 * @param string $options['order']
+	 * @param array   $options
+	 * @param array   $options['imageids']
+	 * @param array   $options['sysmapids']
+	 * @param array   $options['filter']
+	 * @param array   $options['search']
+	 * @param bool    $options['searchByAny']
+	 * @param bool    $options['startSearch']
+	 * @param bool    $options['excludeSearch']
+	 * @param bool    $options['searchWildcardsEnabled']
+	 * @param array   $options['output']
+	 * @param int     $options['select_image']
+	 * @param bool    $options['editable']
+	 * @param bool    $options['countOutput']
+	 * @param bool    $options['preservekeys']
+	 * @param string  $options['sortfield']
+	 * @param string  $options['sortorder']
+	 * @param int     $options['limit']
+	 *
 	 * @return array|boolean image data as array or false if error
 	 */
 	public function get($options = []) {
@@ -69,7 +82,7 @@ class CImage extends CApiService {
 			// output
 			'output'					=> API_OUTPUT_EXTEND,
 			'select_image'				=> null,
-			'editable'					=> null,
+			'editable'					=> false,
 			'countOutput'				=> false,
 			'preservekeys'				=> false,
 			'sortfield'					=> '',
@@ -79,8 +92,8 @@ class CImage extends CApiService {
 		$options = zbx_array_merge($defOptions, $options);
 
 		// editable + PERMISSION CHECK
-		if (!is_null($options['editable']) && self::$userData['type'] < USER_TYPE_ZABBIX_ADMIN) {
-			return $result;
+		if ($options['editable'] && self::$userData['type'] < USER_TYPE_ZABBIX_ADMIN) {
+			return [];
 		}
 
 		// imageids
@@ -128,7 +141,7 @@ class CImage extends CApiService {
 		$imageids = [];
 		$sqlParts = $this->applyQueryOutputOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
-		$res = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
+		$res = DBselect(self::createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($image = DBfetch($res)) {
 			if ($options['countOutput']) {
 				return $image['rowscount'];
@@ -178,6 +191,13 @@ class CImage extends CApiService {
 			// validate image (size and format)
 			$this->checkImage($image['image']);
 
+			list(,, $img_type) = getimagesizefromstring($image['image']);
+
+			if (!in_array($img_type, [IMAGETYPE_GIF, IMAGETYPE_JPEG, IMAGETYPE_PNG])) {
+				// Converting to PNG all images except PNG, JPEG and GIF
+				$image['image'] = $this->convertToPng($image['image']);
+			}
+
 			$imageid = get_dbid('images', 'imageid');
 			$values = [
 				'imageid' => $imageid,
@@ -211,22 +231,6 @@ class CImage extends CApiService {
 					$lob->free();
 					oci_free_statement($stmt);
 				break;
-				case ZBX_DB_DB2:
-					$stmt = db2_prepare($DB['DB'], 'INSERT INTO images ('.implode(' ,', array_keys($values)).',image)'.
-						' VALUES ('.implode(',', $values).', ?)');
-
-					if (!$stmt) {
-						self::exception(ZBX_API_ERROR_PARAMETERS, db2_conn_errormsg($DB['DB']));
-					}
-
-					$variable = $image['image'];
-					if (!db2_bind_param($stmt, 1, "variable", DB2_PARAM_IN, DB2_BINARY)) {
-						self::exception(ZBX_API_ERROR_PARAMETERS, db2_conn_errormsg($DB['DB']));
-					}
-					if (!db2_execute($stmt)) {
-						self::exception(ZBX_API_ERROR_PARAMETERS, db2_conn_errormsg($DB['DB']));
-					}
-				break;
 				case ZBX_DB_MYSQL:
 						$values['image'] = zbx_dbstr($image['image']);
 						$sql = 'INSERT INTO images ('.implode(', ', array_keys($values)).') VALUES ('.implode(', ', $values).')';
@@ -277,6 +281,13 @@ class CImage extends CApiService {
 				// validate image
 				$this->checkImage($image['image']);
 
+				list(,, $img_type) = getimagesizefromstring($image['image']);
+
+				if (!in_array($img_type, [IMAGETYPE_GIF, IMAGETYPE_JPEG, IMAGETYPE_PNG])) {
+					// Converting to PNG all images except PNG, JPEG and GIF
+					$image['image'] = $this->convertToPng($image['image']);
+				}
+
 				switch ($DB['TYPE']) {
 					case ZBX_DB_POSTGRESQL:
 						$values['image'] = "'".pg_escape_bytea($image['image'])."'";
@@ -307,23 +318,6 @@ class CImage extends CApiService {
 						$row['IMAGE']->save($image['image']);
 						$row['IMAGE']->free();
 						break;
-
-					case ZBX_DB_DB2:
-						$stmt = db2_prepare($DB['DB'], 'UPDATE images SET image=? WHERE imageid='.zbx_dbstr($image['imageid']));
-
-						if (!$stmt) {
-							self::exception(ZBX_API_ERROR_PARAMETERS, db2_conn_errormsg($DB['DB']));
-						}
-
-						// not unused, db2_bind_param requires variable name as string
-						$variable = $image['image'];
-						if (!db2_bind_param($stmt, 1, 'variable', DB2_PARAM_IN, DB2_BINARY)) {
-							self::exception(ZBX_API_ERROR_PARAMETERS, db2_conn_errormsg($DB['DB']));
-						}
-						if (!db2_execute($stmt)) {
-							self::exception(ZBX_API_ERROR_PARAMETERS, db2_conn_errormsg($DB['DB']));
-						}
-						break;
 				}
 			}
 
@@ -426,14 +420,18 @@ class CImage extends CApiService {
 	 * @throws APIException if wrong fields are passed.
 	 * @throws APIException if image with same name already exists.
 	 */
-	protected function validateCreate(array $images) {
+	protected function validateCreate(array &$images) {
 		// validate permissions
 		if (self::$userData['type'] < USER_TYPE_ZABBIX_ADMIN) {
 			self::exception(ZBX_API_ERROR_PERMISSIONS, _('No permissions to referred object or it does not exist!'));
 		}
 
+		if (!$images) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+		}
+
 		// check fields
-		foreach ($images as $image) {
+		foreach ($images as &$image) {
 			$imageDbFields = [
 				'name' => null,
 				'image' => null,
@@ -441,9 +439,10 @@ class CImage extends CApiService {
 			];
 
 			if (!check_db_fields($imageDbFields, $image)) {
-				self::exception(ZBX_API_ERROR_PARAMETERS, _s('Wrong fields for image "%1$s".', $image['name']));
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect input parameters.'));
 			}
 		}
+		unset($image);
 
 		// check host name duplicates
 		$collectionValidator = new CCollectionValidator([
@@ -540,8 +539,13 @@ class CImage extends CApiService {
 	 */
 	protected function checkImage($image) {
 		// check size
-		if (strlen($image) > ZBX_MAX_IMAGE_SIZE) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Image size must be less than 1MB.'));
+		if (bccomp(strlen($image), ZBX_MAX_IMAGE_SIZE) == 1) {
+			self::exception(ZBX_API_ERROR_PARAMETERS,
+				_s('Image size must be less than %1$s.', convertUnits([
+					'value' => ZBX_MAX_IMAGE_SIZE,
+					'units' => 'B'
+				]))
+			);
 		}
 
 		// check file format
@@ -551,16 +555,16 @@ class CImage extends CApiService {
 	}
 
 	/**
-	 * Unset "image" field from output.
+	 * Unset "image" field from the output.
 	 *
-	 * @param string $tableName
-	 * @param string $tableAlias
+	 * @param string $table_name
+	 * @param string $table_alias
 	 * @param array  $options
-	 * @param array  $sqlParts
+	 * @param array  $sql_parts
 	 *
-	 * @return array				The resulting SQL parts array
+	 * @return array The resulting SQL parts array.
 	 */
-	protected function applyQueryOutputOptions($tableName, $tableAlias, array $options, array $sqlParts) {
+	protected function applyQueryOutputOptions($table_name, $table_alias, array $options, array $sql_parts) {
 		if (!$options['countOutput']) {
 			if ($options['output'] == API_OUTPUT_EXTEND) {
 				$options['output'] = ['imageid', 'imagetype', 'name'];
@@ -572,10 +576,26 @@ class CImage extends CApiService {
 					}
 				}
 			}
-
-			$sqlParts = parent::applyQueryOutputOptions($tableName, $tableAlias, $options, $sqlParts);
 		}
 
-		return $sqlParts;
+		return parent::applyQueryOutputOptions($table_name, $table_alias, $options, $sql_parts);
+	}
+
+	/**
+	 * Convert image body to PNG.
+	 *
+	 * @param string $image  Base64 encoded body of image.
+	 * @return string
+	 */
+	protected function convertToPng($image) {
+		$image = imagecreatefromstring($image);
+
+		ob_start();
+		imagealphablending($image, false);
+		imagesavealpha($image, true);
+		imagepng($image);
+		imagedestroy($image);
+
+		return ob_get_clean();
 	}
 }
