@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 class CExportWriterFactory {
 
+	const YAML = 'yaml';
 	const XML = 'xml';
 	const JSON = 'json';
 
@@ -36,6 +37,9 @@ class CExportWriterFactory {
 	 */
 	public static function getWriter($type) {
 		switch ($type) {
+			case self::YAML:
+				return new CYamlExportWriter();
+
 			case self::XML:
 				return new CXmlExportWriter();
 
@@ -46,4 +50,33 @@ class CExportWriterFactory {
 				throw new Exception('Incorrect export writer type.');
 		}
 	}
+
+	/**
+	 * Get content mime-type for specified type.
+	 *
+	 * @static
+	 * @throws Exception
+	 *
+	 * @param string $type
+	 *
+	 * @return string
+	 */
+	public static function getMimeType(string $type): string {
+		switch ($type) {
+			case self::YAML:
+				// See https://github.com/rails/rails/blob/d41d586/actionpack/lib/action_dispatch/http/mime_types.rb#L39
+				return 'text/yaml';
+
+			case self::XML:
+				// See https://www.ietf.org/rfc/rfc2376.txt
+				return 'text/xml';
+
+			case self::JSON:
+				// See https://www.ietf.org/rfc/rfc4627.txt
+				return 'application/json';
+
+			default:
+				throw new Exception('Incorrect export writer type.');
+		}
+	}
 }
