@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ class CPageHeader {
 	 */
 	public function __construct($title = '') {
 		$this->title = CHtml::encode($title);
-		$this->sid = substr(get_cookie(ZBX_SESSION_NAME), 16, 16);
+		$this->sid = substr(CSessionHelper::getId(), 16, 16);
 	}
 
 	/**
@@ -121,8 +121,6 @@ class CPageHeader {
 	 * Display page head html.
 	 */
 	public function display() {
-		$assets_path = (new CAssetsFileCache(ZBase::getRootDir()))->getAssetsUrl();
-
 		echo <<<HTML
 <!DOCTYPE html>
 <html>
@@ -133,21 +131,27 @@ class CPageHeader {
 		<meta name="Author" content="Zabbix SIA" />
 		<title>$this->title</title>
 		<link rel="icon" href="favicon.ico">
-		<link rel="apple-touch-icon-precomposed" sizes="76x76" href="{$assets_path}img/apple-touch-icon-76x76-precomposed.png">
-		<link rel="apple-touch-icon-precomposed" sizes="120x120" href="{$assets_path}img/apple-touch-icon-120x120-precomposed.png">
-		<link rel="apple-touch-icon-precomposed" sizes="152x152" href="{$assets_path}img/apple-touch-icon-152x152-precomposed.png">
-		<link rel="apple-touch-icon-precomposed" sizes="180x180" href="{$assets_path}img/apple-touch-icon-180x180-precomposed.png">
-		<link rel="icon" sizes="192x192" href="{$assets_path}img/touch-icon-192x192.png">
+		<link rel="apple-touch-icon-precomposed" sizes="76x76" href="assets/img/apple-touch-icon-76x76-precomposed.png">
+		<link rel="apple-touch-icon-precomposed" sizes="120x120" href="assets/img/apple-touch-icon-120x120-precomposed.png">
+		<link rel="apple-touch-icon-precomposed" sizes="152x152" href="assets/img/apple-touch-icon-152x152-precomposed.png">
+		<link rel="apple-touch-icon-precomposed" sizes="180x180" href="assets/img/apple-touch-icon-180x180-precomposed.png">
+		<link rel="icon" sizes="192x192" href="assets/img/touch-icon-192x192.png">
 		<meta name="csrf-token" content="$this->sid"/>
-		<meta name="msapplication-TileImage" content="{$assets_path}img/ms-tile-144x144.png">
+		<meta name="msapplication-TileImage" content="assets/img/ms-tile-144x144.png">
 		<meta name="msapplication-TileColor" content="#d40000">
 		<meta name="msapplication-config" content="none"/>
 
 HTML;
 
 		foreach ($this->cssFiles as $path) {
-			echo '<link rel="stylesheet" type="text/css" href="',(substr($path, -4) === '.css' ? $assets_path : ''),
-				$path,'" />',"\n";
+			// Add query string only to theme css files.
+			if (in_array($path, ['assets/styles/blue-theme.css', 'assets/styles/dark-theme.css',
+						'assets/styles/hc-light.css', 'assets/styles/hc-dark.css'
+					])) {
+				$path .= '?'.(int) filemtime($path);
+			}
+
+			echo '<link rel="stylesheet" type="text/css" href="'.$path.'" />'."\n";
 		}
 
 		if ($this->styles) {
