@@ -834,6 +834,14 @@ class CHelpItems {
 					'key' => 'vmware.hv.cpu.usage[<url>,<uuid>]',
 					'description' => _('VMware hypervisor processor usage in Hz, <url> - VMware service URL, <uuid> - VMware hypervisor host name')
 				],
+				[
+					'key' => 'vmware.hv.cpu.usage.perf[<url>,<uuid>]',
+					'description' => _('CPU usage as a percentage during the interval, <url> - VMware service URL, <uuid> - VMware hypervisor host name')
+				],
+				[
+					'key' => 'vmware.hv.cpu.utilization[<url>,<uuid>]',
+					'description' => _('CPU usage as a percentage during the interval depends on power management or HT, <url> - VMware service URL, <uuid> - VMware hypervisor host name')
+				],
 				[
 					'key' => 'vmware.hv.datacenter.name[<url>,<uuid>]',
 					'description' => _('VMware hypervisor datacenter name, <url> - VMware service URL, <uuid> - VMware hypervisor host name. Returns string')
@@ -846,6 +854,10 @@ class CHelpItems {
 					'key' => 'vmware.hv.datastore.list[<url>,<uuid>]',
 					'description' => _('VMware hypervisor datastores list, <url> - VMware service URL, <uuid> - VMware hypervisor host name')
 				],
+				[
+					'key' => 'vmware.hv.datastore.multipath[<url>,<uuid>,<datastore>,<partitionid>]',
+					'description' => _('Number of available DS paths, <url> - VMware service URL, <uuid> - VMware hypervisor host name, <datastore> - Datastore name, <partitionid> - internal id of physical device from vmware.hv.datastore.discovery')
+				],
 				[
 					'key' => 'vmware.hv.datastore.read[<url>,<uuid>,<datastore>,<mode>]',
 					'description' => _('VMware hypervisor datastore read statistics, <url> - VMware service URL, <uuid> - VMware hypervisor host name, <datastore> - datastore name, <mode> - latency')
@@ -918,6 +930,10 @@ class CHelpItems {
 					'key' => 'vmware.hv.perfcounter[<url>,<uuid>,<path>,<instance>]',
 					'description' => _('VMware hypervisor performance counter, <url> - VMware service URL, <uuid> - VMware hypervisor host name, <path> - performance counter path, <instance> - performance counter instance')
 				],
+				[
+					'key' => 'vmware.hv.power[<url>,<uuid>,<max>]',
+					'description' => _('Power usage , <url> - VMware service URL, <uuid> - VMware hypervisor host name, <max> - Maximum allowed power usage')
+				],
 				[
 					'key' => 'vmware.hv.sensor.health.state[<url>,<uuid>]',
 					'description' => _('VMware hypervisor health state rollup sensor, <url> - VMware service URL, <uuid> - VMware hypervisor host name. Returns 0 - gray; 1 - green; 2 - yellow; 3 - red')
@@ -946,18 +962,34 @@ class CHelpItems {
 					'key' => 'vmware.vm.cluster.name[<url>,<uuid>]',
 					'description' => _('VMware virtual machine name, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.cpu.latency[<url>,<uuid>]',
+					'description' => _('Percent of time the virtual machine is unable to run because it is contending for access to the physical CPU(s), <url> - VMware service URL, <uuid> - VMware virtual machine host name')
+				],
 				[
 					'key' => 'vmware.vm.cpu.num[<url>,<uuid>]',
 					'description' => _('Number of processors on VMware virtual machine, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.cpu.readiness[<url>,<uuid>,<instance>]',
+					'description' => _('Percentage of time that the virtual machine was ready, but could not get scheduled to run on the physical CPU, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - CPU instance')
+				],
 				[
 					'key' => 'vmware.vm.cpu.ready[<url>,<uuid>]',
 					'description' => _('VMware virtual machine processor ready time ms, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.cpu.swapwait[<url>,<uuid>,<instance>]',
+					'description' => _('CPU time spent waiting for swap-in, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - CPU instance')
+				],
 				[
 					'key' => 'vmware.vm.cpu.usage[<url>,<uuid>]',
 					'description' => _('VMware virtual machine processor usage in Hz, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.cpu.usage.perf[<url>,<uuid>]',
+					'description' => _('CPU usage as a percentage during the interval, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
+				],
 				[
 					'key' => 'vmware.vm.datacenter.name[<url>,<uuid>]',
 					'description' => _('VMware virtual machine datacenter name, <url> - VMware service URL, <uuid> - VMware virtual machine host name. Returns string')
@@ -966,7 +998,15 @@ class CHelpItems {
 					'key' => 'vmware.vm.discovery[<url>]',
 					'description' => _('Discovery of VMware virtual machines, <url> - VMware service URL. Returns JSON')
 				],
-								[
+				[
+					'key' => 'vmware.vm.guest.memory.size.swapped[<url>,<uuid>]',
+					'description' => _('Amount of guest physical memory that is swapped out to the swap space, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
+				],
+				[
+					'key' => 'vmware.vm.guest.osuptime[<url>,<uuid>]',
+					'description' => _('Total time elapsed, in seconds, since last operating system boot-up, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
+				],
+				[
 					'key' => 'vmware.vm.hv.name[<url>,<uuid>]',
 					'description' => _('VMware virtual machine hypervisor name, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
@@ -982,6 +1022,10 @@ class CHelpItems {
 					'key' => 'vmware.vm.memory.size.compressed[<url>,<uuid>]',
 					'description' => _('VMware virtual machine compressed memory size, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.memory.size.consumed[<url>,<uuid>]',
+					'description' => _('Amount of host physical memory consumed for backing up guest physical memory pages, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
+				],
 				[
 					'key' => 'vmware.vm.memory.size.private[<url>,<uuid>]',
 					'description' => _('VMware virtual machine private memory size, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
@@ -1002,6 +1046,10 @@ class CHelpItems {
 					'key' => 'vmware.vm.memory.size.usage.host[<url>,<uuid>]',
 					'description' => _('VMware virtual machine host memory usage, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.memory.usage[<url>,<uuid>]',
+					'description' => _('Percentage of host physical memory that has been consumed, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
+				],
 				[
 					'key' => 'vmware.vm.net.if.discovery[<url>,<uuid>]',
 					'description' => 'Discovery of VMware virtual machine network interfaces, <url> - VMware service URL, <uuid> - VMware virtual machine host name. Returns JSON'
@@ -1014,6 +1062,10 @@ class CHelpItems {
 					'key' => 'vmware.vm.net.if.out[<url>,<uuid>,<instance>,<mode>]',
 					'description' => _('VMware virtual machine network interface output statistics, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - network interface instance, <mode> - bps/pps - bytes/packets per second')
 				],
+				[
+					'key' => 'vmware.vm.net.if.usage[<url>,<uuid>,<instance>]',
+					'description' => _('Network utilization (combined transmit-rates and receive-rates) during the interval, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - network interface instance')
+				],
 				[
 					'key' => 'vmware.vm.perfcounter[<url>,<uuid>,<path>,<instance>]',
 					'description' => _('VMware virtual machine performance counter, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <path> - performance counter path, <instance> - performance counter instance')
@@ -1026,6 +1078,18 @@ class CHelpItems {
 					'key' => 'vmware.vm.storage.committed[<url>,<uuid>]',
 					'description' => _('VMware virtual machine committed storage space, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.storage.readoio[<url>,<uuid>,<instance>]',
+					'description' => _('Average number of outstanding read requests to the virtual disk during the collection interval , <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - disk device instance')
+				],
+				[
+					'key' => 'vmware.vm.storage.totalreadlatency[<url>,<uuid>,<instance>]',
+					'description' => _('	The average time a read from the virtual disk takes , <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - disk device instance')
+				],
+				[
+					'key' => 'vmware.vm.storage.totalwritelatency[<url>,<uuid>,<instance>]',
+					'description' => _('The average time a write to the virtual disk takes, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - disk device instance')
+				],
 				[
 					'key' => 'vmware.vm.storage.uncommitted[<url>,<uuid>]',
 					'description' => _('VMware virtual machine uncommitted storage space, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
@@ -1034,6 +1098,10 @@ class CHelpItems {
 					'key' => 'vmware.vm.storage.unshared[<url>,<uuid>]',
 					'description' => _('VMware virtual machine unshared storage space, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
 				],
+				[
+					'key' => 'vmware.vm.storage.writeoio[<url>,<uuid>,<instance>]',
+					'description' => _('Average number of outstanding write requests to the virtual disk during the collection interval, <url> - VMware service URL, <uuid> - VMware virtual machine host name, <instance> - disk device instance')
+				],
 				[
 					'key' => 'vmware.vm.uptime[<url>,<uuid>]',
 					'description' => _('VMware virtual machine uptime, <url> - VMware service URL, <uuid> - VMware virtual machine host name')
