@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -51,6 +51,17 @@ class CZabbixServer {
 	 */
 	const RESPONSE_FAILED = 'failed';
 
+	/**
+	 * Auxiliary constants for request() method.
+	 */
+	const ZBX_TCP_EXPECT_HEADER = 1;
+	const ZBX_TCP_EXPECT_DATA = 2;
+
+	/**
+	 * Max number of bytes to read from the response for each each iteration.
+	 */
+	const READ_BYTES_LIMIT = 8192;
+
 	/**
 	 * Zabbix server host name.
 	 *
@@ -65,6 +76,13 @@ class CZabbixServer {
 	 */
 	protected $port;
 
+	/**
+	 * Request connect timeout.
+	 *
+	 * @var int
+	 */
+	protected $connect_timeout;
+
 	/**
 	 * Request timeout.
 	 *
@@ -79,13 +97,6 @@ class CZabbixServer {
 	 */
 	protected $totalBytesLimit;
 
-	/**
-	 * Bite count to read from the response with each iteration.
-	 *
-	 * @var int
-	 */
-	protected $readBytesLimit = 8192;
-
 	/**
 	 * Zabbix server socket resource.
 	 *
@@ -107,17 +118,24 @@ class CZabbixServer {
 	 */
 	protected $total;
 
+	/**
+	 * @var array $debug  Section 'debug' data from server response.
+	 */
+	protected $debug = [];
+
 	/**
 	 * Class constructor.
 	 *
 	 * @param string $host
 	 * @param int $port
+	 * @param int $connect_timeout
 	 * @param int $timeout
 	 * @param int $totalBytesLimit
 	 */
-	public function __construct($host, $port, $timeout, $totalBytesLimit) {
+	public function __construct($host, $port, $connect_timeout, $timeout, $totalBytesLimit) {
 		$this->host = $host;
 		$this->port = $port;
+		$this->connect_timeout = $connect_timeout;
 		$this->timeout = $timeout;
 		$this->totalBytesLimit = $totalBytesLimit;
 	}
@@ -136,6 +154,55 @@ class CZabbixServer {
 			'request' => 'command',
 			'scriptid' => $scriptId,
 			'hostid' => $hostId,
+			'sid' => $sid,
+			'clientip' => CWebUser::getIp()
+		]);
+	}
+
+	/**
+	 * Request server to test item preprocessing steps.
+	 *
+	 * @param array  $data                                     Array of preprocessing steps test.
+	 * @param string $data['value']                            Value to use for preprocessing step testing.
+	 * @param int    $data['value_type']                       Item value type.
+	 * @param array  $data['history']                          Previous value object.
+	 * @param string $data['history']['value']                 Previous value.
+	 * @param string $data['history']['timestamp']             Previous value time.
+	 * @param array  $data['steps']                            Preprocessing step object.
+	 * @param int    $data['steps'][]['type']                  Type of preprocessing step.
+	 * @param string $data['steps'][]['params']                Parameters of preprocessing step.
+	 * @param int    $data['steps'][]['error_handler']         Error handler selected as "custom on fail".
+	 * @param string $data['steps'][]['error_handler_params']  Parameters configured for selected error handler.
+	 * @param string $sid                                      User session ID.
+	 *
+	 * @return array
+	 */
+	public function testPreprocessingSteps(array $data, $sid) {
+		return $this->request([
+			'request' => 'preprocessing.test',
+			'data' => $data,
+			'sid' => $sid
+		]);
+	}
+
+	/**
+	 * Request server to test item.
+	 *
+	 * @param array  $data    Array of item properties to test.
+	 * @param string $sid     User session ID.
+	 *
+	 * @return array
+	 */
+	public function testItem(array $data, $sid) {
+		/*
+		 * Timeout for 'item.test' request is increased because since message can be forwarded from server to proxy and
+		 * later to agent, it might take more time due network latency.
+		 */
+		$this->timeout = 60;
+
+		return $this->request([
+			'request' => 'item.test',
+			'data' => $data,
 			'sid' => $sid
 		]);
 	}
@@ -169,7 +236,28 @@ class CZabbixServer {
 	}
 
 	/**
-	 * Retrieve Status of Zabbix information.
+	 * Request server to test media type.
+	 *
+	 * @param array  $data                 Array of media type test data to send.
+	 * @param string $data['mediatypeid']  Media type ID.
+	 * @param string $data['sendto']       Message destination.
+	 * @param string $data['subject']      Message subject.
+	 * @param string $data['message']      Message body.
+	 * @param string $data['params']       Custom parameters for media type webhook.
+	 * @param string $sid                  User session ID.
+	 *
+	 * @return bool|array
+	 */
+	public function testMediaType(array $data, $sid) {
+		return $this->request([
+			'request' => 'alert.send',
+			'sid' => $sid,
+			'data' => $data
+		]);
+	}
+
+	/**
+	 * Retrieve System information.
 	 *
 	 * @param $sid
 	 *
@@ -256,6 +344,38 @@ class CZabbixServer {
 		return CApiInputValidator::validate($api_input_rules, $response, '/', $this->error);
 	}
 
+	/**
+	 * Evaluate trigger expressions.
+	 *
+	 * @param array  $data
+	 * @param string $sid
+	 *
+	 * @return bool|array
+	 */
+	public function expressionsEvaluate(array $data, string $sid) {
+		$response = $this->request([
+			'request' => 'expressions.evaluate',
+			'sid' => $sid,
+			'data' => $data
+		]);
+
+		if ($response === false) {
+			return false;
+		}
+
+		$api_input_rules = ['type' => API_OBJECTS, 'fields' => [
+			'expression' =>	['type' => API_STRING_UTF8, 'flags' => API_REQUIRED],
+			'value' =>		['type' => API_INT32, 'in' => '0,1'],
+			'error' =>		['type' => API_STRING_UTF8]
+		]];
+
+		if (!CApiInputValidator::validate($api_input_rules, $response, '/', $this->error)) {
+			return false;
+		}
+
+		return $response;
+	}
+
 	/**
 	 * Returns the error message.
 	 *
@@ -274,6 +394,15 @@ class CZabbixServer {
 		return $this->total;
 	}
 
+	/**
+	 * Returns debug section from server response.
+	 *
+	 * @return array
+	 */
+	public function getDebug() {
+		return $this->debug;
+	}
+
 	/**
 	 * Executes a given JSON request and returns the result. Returns false if an error has occurred.
 	 *
@@ -282,86 +411,117 @@ class CZabbixServer {
 	 * @return mixed    the output of the script if it has been executed successfully or false otherwise
 	 */
 	protected function request(array $params) {
-		// reset object state
+		// Reset object state.
 		$this->error = null;
 		$this->total = null;
+		$this->debug = [];
 
-		// connect to the server
+		// Connect to the server.
 		if (!$this->connect()) {
 			return false;
 		}
 
-		// set timeout
+		// Set timeout.
 		stream_set_timeout($this->socket, $this->timeout);
 
-		// send the command
-		if (fwrite($this->socket, CJs::encodeJson($params)) === false) {
+		// Send the command.
+		$json = json_encode($params);
+		if (fwrite($this->socket, ZBX_TCP_HEADER.pack('V', strlen($json))."\x00\x00\x00\x00".$json) === false) {
 			$this->error = _s('Cannot send command, check connection with Zabbix server "%1$s".', $this->host);
-
 			return false;
 		}
 
-		// read the response
-		$readBytesLimit = ($this->totalBytesLimit && $this->totalBytesLimit < $this->readBytesLimit)
-			? $this->totalBytesLimit
-			: $this->readBytesLimit;
-
+		$expect = self::ZBX_TCP_EXPECT_HEADER;
 		$response = '';
+		$response_len = 0;
+		$expected_len = null;
 		$now = time();
-		$i = 0;
-		while (!feof($this->socket)) {
-			$i++;
+
+		while (true) {
 			if ((time() - $now) >= $this->timeout) {
-				$this->error = _s('Connection timeout of %1$s seconds exceeded when connecting to Zabbix server "%2$s".', $this->timeout, $this->host);
-
-				return false;
-			}
-			elseif ($this->totalBytesLimit && ($i * $readBytesLimit) >= $this->totalBytesLimit) {
-				$this->error = _s('Size of the response received from Zabbix server "%1$s" exceeds the allowed size of %2$s bytes. This value can be increased in the ZBX_SOCKET_BYTES_LIMIT constant in include/defines.inc.php.', $this->host, $this->totalBytesLimit);
-
+				$this->error = _s(
+					'Connection timeout of %1$s seconds exceeded when connecting to Zabbix server "%2$s".',
+					$this->timeout, $this->host
+				);
 				return false;
 			}
 
-			if (($out = fread($this->socket, $readBytesLimit)) !== false) {
-				$response .= $out;
+			if (!feof($this->socket) && ($buffer = fread($this->socket, self::READ_BYTES_LIMIT)) !== false) {
+				$response_len += strlen($buffer);
+				$response .= $buffer;
+
+				if ($expect == self::ZBX_TCP_EXPECT_HEADER) {
+					if (strncmp($response, ZBX_TCP_HEADER, min($response_len, ZBX_TCP_HEADER_LEN)) != 0) {
+						$this->error = _s('Incorrect response received from Zabbix server "%1$s".', $this->host);
+						return false;
+					}
+
+					if ($response_len < ZBX_TCP_HEADER_LEN) {
+						continue;
+					}
+
+					$expect = self::ZBX_TCP_EXPECT_DATA;
+				}
+
+				if ($response_len < ZBX_TCP_HEADER_LEN + ZBX_TCP_DATALEN_LEN) {
+					continue;
+				}
+
+				if ($expected_len === null) {
+					$expected_len = unpack('Vlen', substr($response, ZBX_TCP_HEADER_LEN, 4))['len'];
+					$expected_len += ZBX_TCP_HEADER_LEN + ZBX_TCP_DATALEN_LEN;
+
+					if ($this->totalBytesLimit != 0 && $expected_len >= $this->totalBytesLimit) {
+						$this->error = _s(
+							'Size of the response received from Zabbix server "%1$s" exceeds the allowed size of %2$s bytes. This value can be increased in the ZBX_SOCKET_BYTES_LIMIT constant in include/defines.inc.php.',
+							$this->host, $this->totalBytesLimit
+						);
+						return false;
+					}
+				}
+
+				if ($response_len >= $expected_len) {
+					break;
+				}
 			}
 			else {
-				$this->error = _s('Cannot read the response, check connection with the Zabbix server "%1$s".', $this->host);
-
+				$this->error =
+					_s('Cannot read the response, check connection with the Zabbix server "%1$s".', $this->host);
 				return false;
 			}
 		}
 
 		fclose($this->socket);
 
-		// check if the response is empty
-		if (!strlen($response)) {
-			$this->error = _s('Empty response received from Zabbix server "%1$s".', $this->host);
-
+		if ($expected_len > $response_len || $response_len > $expected_len) {
+			$this->error = _s('Incorrect response received from Zabbix server "%1$s".', $this->host);
 			return false;
 		}
 
-		$response = CJs::decodeJson($response);
+		$response = json_decode(substr($response, ZBX_TCP_HEADER_LEN + ZBX_TCP_DATALEN_LEN), true);
 
-		if (!$response || !$this->validateResponse($response)) {
+		if (!$response || !$this->normalizeResponse($response)) {
 			$this->error = _s('Incorrect response received from Zabbix server "%1$s".', $this->host);
 
 			return false;
 		}
 
-		// request executed successfully
+		if (array_key_exists('debug', $response)) {
+			$this->debug = $response['debug'];
+		}
+
+		// Request executed successfully.
 		if ($response['response'] == self::RESPONSE_SUCCESS) {
 			// saves total count
 			$this->total = array_key_exists('total', $response) ? $response['total'] : null;
 
-			return $response['data'];
+			return array_key_exists('data', $response) ? $response['data'] : true;
 		}
-		// an error on the server side occurred
-		else {
-			$this->error = $response['info'];
 
-			return false;
-		}
+		// An error on the server side occurred.
+		$this->error = $response['info'];
+
+		return false;
 	}
 
 	/**
@@ -376,22 +536,22 @@ class CZabbixServer {
 				return false;
 			}
 
-			if (!$socket = @fsockopen($this->host, $this->port, $errorCode, $errorMsg, $this->timeout)) {
+			if (!$socket = @fsockopen($this->host, $this->port, $errorCode, $errorMsg, $this->connect_timeout)) {
 				switch ($errorMsg) {
 					case 'Connection refused':
-						$dErrorMsg = _s("Connection to Zabbix server \"%s\" refused. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Security environment (for example, SELinux) is blocking the connection;\n3. Zabbix server daemon not running;\n4. Firewall is blocking TCP connection.\n", $this->host);
+						$dErrorMsg = _s("Connection to Zabbix server \"%1\$s\" refused. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Security environment (for example, SELinux) is blocking the connection;\n3. Zabbix server daemon not running;\n4. Firewall is blocking TCP connection.\n", $this->host);
 						break;
 
 					case 'No route to host':
-						$dErrorMsg = _s("Zabbix server \"%s\" can not be reached. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Incorrect network configuration.\n", $this->host);
+						$dErrorMsg = _s("Zabbix server \"%1\$s\" can not be reached. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Incorrect network configuration.\n", $this->host);
 						break;
 
 					case 'Connection timed out':
-						$dErrorMsg = _s("Connection to Zabbix server \"%s\" timed out. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Firewall is blocking TCP connection.\n", $this->host);
+						$dErrorMsg = _s("Connection to Zabbix server \"%1\$s\" timed out. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Firewall is blocking TCP connection.\n", $this->host);
 						break;
 
 					default:
-						$dErrorMsg = _s("Connection to Zabbix server \"%s\" failed. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Incorrect DNS server configuration.\n", $this->host);
+						$dErrorMsg = _s("Connection to Zabbix server \"%1\$s\" failed. Possible reasons:\n1. Incorrect server IP/DNS in the \"zabbix.conf.php\";\n2. Incorrect DNS server configuration.\n", $this->host);
 				}
 
 				$this->error = $dErrorMsg.$errorMsg;
@@ -410,9 +570,9 @@ class CZabbixServer {
 	 *
 	 * @return bool
 	 */
-	protected function validateResponse(array $response) {
-		return (isset($response['response'])
-					&& ($response['response'] == self::RESPONSE_SUCCESS && isset($response['data'])
-						|| $response['response'] == self::RESPONSE_FAILED && isset($response['info'])));
+	protected function normalizeResponse(array &$response) {
+		return (array_key_exists('response', $response) && ($response['response'] == self::RESPONSE_SUCCESS
+				|| $response['response'] == self::RESPONSE_FAILED && array_key_exists('info', $response))
+		);
 	}
 }
