@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -21,8 +21,8 @@
 
 class CWidgetFormSvgGraph extends CWidgetForm {
 
-	public function __construct($data) {
-		parent::__construct($data, WIDGET_SVG_GRAPH);
+	public function __construct($data, $templateid) {
+		parent::__construct($data, $templateid, WIDGET_SVG_GRAPH);
 
 		$this->data = self::convertDottedKeys($this->data);
 
@@ -153,14 +153,11 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		$this->fields[$field_lefty_max->getName()] = $field_lefty_max;
 
 		// Specify the type of units on left Y axis.
-		$field_lefty_units = (new CWidgetFieldComboBox('lefty_units', _('Units'), [
+		$field_lefty_units = (new CWidgetFieldSelect('lefty_units', _('Units'), [
 			SVG_GRAPH_AXIS_UNITS_AUTO => _x('Auto', 'history source selection method'),
 			SVG_GRAPH_AXIS_UNITS_STATIC => _x('Static', 'history source selection method')
 		]))
-			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO)
-			->setAction('jQuery("#lefty_static_units")'.
-							'.prop("disabled", (jQuery(this).val() != "'.SVG_GRAPH_AXIS_UNITS_STATIC.'"))'
-			);
+			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO);
 
 		if ($field_lefty->getValue() != SVG_GRAPH_AXIS_SHOW) {
 			$field_lefty_units->setFlags(CWidgetField::FLAG_DISABLED);
@@ -228,14 +225,11 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 		$this->fields[$field_righty_max->getName()] = $field_righty_max;
 
 		// Specify the type of units on right Y axis.
-		$field_righty_units = (new CWidgetFieldComboBox('righty_units', _('Units'), [
+		$field_righty_units = (new CWidgetFieldSelect('righty_units', _('Units'), [
 			SVG_GRAPH_AXIS_UNITS_AUTO => _x('Auto', 'history source selection method'),
 			SVG_GRAPH_AXIS_UNITS_STATIC => _x('Static', 'history source selection method')
 		]))
-			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO)
-			->setAction('jQuery("#righty_static_units")'.
-							'.prop("disabled", (jQuery(this).val() != "'.SVG_GRAPH_AXIS_UNITS_STATIC.'"))'
-			);
+			->setDefault(SVG_GRAPH_AXIS_UNITS_AUTO);
 
 		if ($field_righty->getValue() != SVG_GRAPH_AXIS_SHOW) {
 			$field_righty_units->setFlags(CWidgetField::FLAG_DISABLED);
@@ -432,23 +426,30 @@ class CWidgetFormSvgGraph extends CWidgetForm {
 	private static function validateTimeSelectorPeriod($from, $to) {
 		$errors = [];
 		$ts = [];
+		$ts['now'] = time();
 		$range_time_parser = new CRangeTimeParser();
 
 		foreach (['from' => $from, 'to' => $to] as $field => $value) {
 			$range_time_parser->parse($value);
-			$ts[$field] = $range_time_parser->getDateTime($field === 'from')->getTimestamp();
+			$ts[$field] = $range_time_parser
+				->getDateTime($field === 'from')
+				->getTimestamp();
 		}
 
 		$period = $ts['to'] - $ts['from'] + 1;
+		$range_time_parser->parse('now-'.CSettingsHelper::get(CSettingsHelper::MAX_PERIOD));
+		$max_period = 1 + $ts['now'] - $range_time_parser
+			->getDateTime(true)
+			->getTimestamp();
 
 		if ($period < ZBX_MIN_PERIOD) {
 			$errors[] = _n('Minimum time period to display is %1$s minute.',
 				'Minimum time period to display is %1$s minutes.', (int) (ZBX_MIN_PERIOD / SEC_PER_MIN)
 			);
 		}
-		elseif ($period > ZBX_MAX_PERIOD) {
+		elseif ($period > $max_period) {
 			$errors[] = _n('Maximum time period to display is %1$s day.',
-				'Maximum time period to display is %1$s days.', (int) (ZBX_MAX_PERIOD / SEC_PER_DAY)
+				'Maximum time period to display is %1$s days.', (int) ($max_period / SEC_PER_DAY)
 			);
 		}
 
