@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -134,28 +134,48 @@ function get_events_unacknowledged($db_element, $value_trigger = null, $value_ev
 
 /**
  *
- * @param array  $event                      An array of event data.
- * @param string $event['eventid']           Event ID.
- * @param string $event['objectid']          Object ID.
- * @param string $event['correlationid']     OK Event correlation ID.
- * @param string $event['userid']            User ID who generated the OK event.
- * @param string $event['name']              Event name.
- * @param string $event['acknowledged']      State of acknowledgement.
- * @param CCOl   $event['opdata']            Operational data with expanded macros.
- * @param string $event['comments']          Trigger description with expanded macros.
- * @param array  $allowed                    An array of user role rules.
- * @param bool   $allowed['ack']             Whether user is allowed to make acknowledge actions.
- * @param bool   $allowed['ui_correlation']  Whether user is allowed to visit event correlation page.
+ * @param array  $event                              An array of event data.
+ * @param string $event['eventid']                   Event ID.
+ * @param string $event['r_eventid']                 OK event ID.
+ * @param string $event['objectid']                  Object ID.
+ * @param string $event['correlationid']             OK Event correlation ID.
+ * @param string $event['userid']                    User ID who generated the OK event.
+ * @param string $event['name']                      Event name.
+ * @param string $event['acknowledged']              State of acknowledgement.
+ * @param array  $event['acknowledges']              List of problem updates.
+ * @param string $event['acknowledges'][]['action']  Action performed in update.
+ * @param CCOl   $event['opdata']                    Operational data with expanded macros.
+ * @param string $event['comments']                  Trigger description with expanded macros.
+ * @param array  $allowed                            An array of user role rules.
+ * @param bool   $allowed['ui_correlation']          Whether user is allowed to visit event correlation page.
+ * @param bool   $allowed['add_comments']            Whether user is allowed to add problems comments.
+ * @param bool   $allowed['change_severity']         Whether user is allowed to change problems severity.
+ * @param bool   $allowed['acknowledge']             Whether user is allowed to acknowledge problems.
+ * @param bool   $allowed['close']                   Whether user is allowed to close problems.
  *
  * @return CTableInfo
  */
 function make_event_details(array $event, array $allowed) {
+	$can_be_closed = $allowed['close'];
+
+	if ($event['r_eventid'] != 0) {
+		$can_be_closed = false;
+	}
+	else {
+		foreach ($event['acknowledges'] as $acknowledge) {
+			if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
+				$can_be_closed = false;
+				break;
+			}
+		}
+	}
+
 	$is_acknowledged = ($event['acknowledged'] == EVENT_ACKNOWLEDGED);
 
 	$table = (new CTableInfo())
 		->addRow([
 			_('Event'),
-			$event['name']
+			(new CCol($event['name']))->addClass(ZBX_STYLE_WORDWRAP)
 		])
 		->addRow([
 			_('Operational data'),
@@ -171,7 +191,7 @@ function make_event_details(array $event, array $allowed) {
 		])
 		->addRow([
 			_('Acknowledged'),
-			$allowed['ack']
+			($allowed['add_comments'] || $allowed['change_severity'] || $allowed['acknowledge'] || $can_be_closed)
 				? (new CLink($is_acknowledged ? _('Yes') : _('No')))
 					->addClass($is_acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
 					->addClass(ZBX_STYLE_LINK_ALT)
@@ -244,11 +264,14 @@ function make_event_details(array $event, array $allowed) {
 
 /**
  *
- * @param array  $startEvent              An array of event data.
- * @param string $startEvent['eventid']   Event ID.
- * @param string $startEvent['objectid']  Object ID.
- * @param array  $allowed                 An array of user role rules.
- * @param bool   $allowed['ack']          Whether user is allowed to make acknowledge actions.
+ * @param array  $startEvent                  An array of event data.
+ * @param string $startEvent['eventid']       Event ID.
+ * @param string $startEvent['objectid']      Object ID.
+ * @param array  $allowed                     An array of user role rules.
+ * @param bool   $allowed['add_comments']     Whether user is allowed to add problems comments.
+ * @param bool   $allowed['change_severity']  Whether user is allowed to change problems severity.
+ * @param bool   $allowed['acknowledge']      Whether user is allowed to acknowledge problems.
+ * @param bool   $allowed['close']            Whether user is allowed to close problems.
  *
  * @return CTableInfo
  */
@@ -331,12 +354,21 @@ function make_small_eventlist(array $startEvent, array $allowed) {
 			? zbx_date2age($event['clock'], $event['r_clock'])
 			: zbx_date2age($event['clock']);
 
-		if ($event['r_eventid'] == 0) {
+		$can_be_closed = $allowed['close'];
+
+		if ($event['r_eventid'] != 0) {
+			$value = TRIGGER_VALUE_FALSE;
+			$value_str = _('RESOLVED');
+			$value_clock = $event['r_clock'];
+			$can_be_closed = false;
+		}
+		else {
 			$in_closing = false;
 
 			foreach ($event['acknowledges'] as $acknowledge) {
 				if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
 					$in_closing = true;
+					$can_be_closed = false;
 					break;
 				}
 			}
@@ -345,11 +377,6 @@ function make_small_eventlist(array $startEvent, array $allowed) {
 			$value_str = $in_closing ? _('CLOSING') : _('PROBLEM');
 			$value_clock = $in_closing ? time() : $event['clock'];
 		}
-		else {
-			$value = TRIGGER_VALUE_FALSE;
-			$value_str = _('RESOLVED');
-			$value_clock = $event['r_clock'];
-		}
 
 		$is_acknowledged = ($event['acknowledged'] == EVENT_ACKNOWLEDGED);
 		$cell_status = new CSpan($value_str);
@@ -361,7 +388,8 @@ function make_small_eventlist(array $startEvent, array $allowed) {
 		addTriggerValueStyle($cell_status, $value, $value_clock, $is_acknowledged);
 
 		// Create acknowledge link.
-		$problem_update_link = $allowed['ack']
+		$problem_update_link = ($allowed['add_comments'] || $allowed['change_severity'] || $allowed['acknowledge']
+				|| $can_be_closed)
 			? (new CLink($is_acknowledged ? _('Yes') : _('No')))
 				->addClass($is_acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
 				->addClass(ZBX_STYLE_LINK_ALT)
@@ -393,29 +421,32 @@ function make_small_eventlist(array $startEvent, array $allowed) {
 /**
  * Create table with trigger description and events.
  *
- * @param array  $trigger                    An array of trigger data.
- * @param string $trigger['triggerid']       Trigger ID to select events.
- * @param string $trigger['comments']        Trigger description.
- * @param string $trigger['url']             Trigger URL.
+ * @param array  $trigger                     An array of trigger data.
+ * @param string $trigger['triggerid']        Trigger ID to select events.
+ * @param string $trigger['comments']         Trigger description.
+ * @param string $trigger['url']              Trigger URL.
  * @param string $eventid_till
- * @param array  $allowed                    An array of user role rules.
- * @param bool   $allowed['ui_problems']     Whether user is allowed to visit problems page.
- * @param bool   $allowed['ack']             Whether user is allowed to make acknowledge actions.
- * @param bool   $show_timeline              Show time line flag.
- * @param int    $show_tags                  Show tags flag. Possible values:
- *                                             - PROBLEMS_SHOW_TAGS_NONE;
- *                                             - PROBLEMS_SHOW_TAGS_1;
- *                                             - PROBLEMS_SHOW_TAGS_2;
- *                                             - PROBLEMS_SHOW_TAGS_3 (default).
- * @param array  $filter_tags                An array of tag filtering data.
- * @param string $filter_tags[]['tag']       Tag name.
- * @param int    $filter_tags[]['operator']  Tag operator.
- * @param string $filter_tags[]['value']     Tag value.
- * @param int    $tag_name_format            Tag name format. Possible values:
- *                                             - PROBLEMS_TAG_NAME_FULL (default);
- *                                             - PROBLEMS_TAG_NAME_SHORTENED;
- *                                             - PROBLEMS_TAG_NAME_NONE.
- * @param string $tag_priority               A list of comma-separated tag names.
+ * @param array  $allowed                     An array of user role rules.
+ * @param bool   $allowed['ui_problems']      Whether user is allowed to visit problems page.
+ * @param bool   $allowed['add_comments']     Whether user is allowed to add problems comments.
+ * @param bool   $allowed['change_severity']  Whether user is allowed to change problems severity.
+ * @param bool   $allowed['acknowledge']      Whether user is allowed to acknowledge problems.
+ * @param bool   $allowed['close']            Whether user is allowed to close problems.
+ * @param bool   $show_timeline               Show time line flag.
+ * @param int    $show_tags                   Show tags flag. Possible values:
+ *                                              - PROBLEMS_SHOW_TAGS_NONE;
+ *                                              - PROBLEMS_SHOW_TAGS_1;
+ *                                              - PROBLEMS_SHOW_TAGS_2;
+ *                                              - PROBLEMS_SHOW_TAGS_3 (default).
+ * @param array  $filter_tags                 An array of tag filtering data.
+ * @param string $filter_tags[]['tag']        Tag name.
+ * @param int    $filter_tags[]['operator']   Tag operator.
+ * @param string $filter_tags[]['value']      Tag value.
+ * @param int    $tag_name_format             Tag name format. Possible values:
+ *                                              - PROBLEMS_TAG_NAME_FULL (default);
+ *                                              - PROBLEMS_TAG_NAME_SHORTENED;
+ *                                              - PROBLEMS_TAG_NAME_NONE.
+ * @param string $tag_priority                A list of comma-separated tag names.
  *
  * @return CDiv
  */
@@ -533,10 +564,13 @@ function make_popup_eventlist($trigger, $eventid_till, $allowed, $show_timeline
 				$problem['userid'] = 0;
 			}
 
+			$can_be_closed = $allowed['close'];
+
 			if ($problem['r_eventid'] != 0) {
 				$value = TRIGGER_VALUE_FALSE;
 				$value_str = _('RESOLVED');
 				$value_clock = $problem['r_clock'];
+				$can_be_closed = false;
 			}
 			else {
 				$in_closing = false;
@@ -544,6 +578,7 @@ function make_popup_eventlist($trigger, $eventid_till, $allowed, $show_timeline
 				foreach ($problem['acknowledges'] as $acknowledge) {
 					if (($acknowledge['action'] & ZBX_PROBLEM_UPDATE_CLOSE) == ZBX_PROBLEM_UPDATE_CLOSE) {
 						$in_closing = true;
+						$can_be_closed = false;
 						break;
 					}
 				}
@@ -611,7 +646,8 @@ function make_popup_eventlist($trigger, $eventid_till, $allowed, $show_timeline
 			}
 
 			// Create acknowledge link.
-			$problem_update_link = $allowed['ack']
+			$problem_update_link = ($allowed['add_comments'] || $allowed['change_severity'] || $allowed['acknowledge']
+					|| $can_be_closed)
 				? (new CLink($is_acknowledged ? _('Yes') : _('No')))
 					->addClass($is_acknowledged ? ZBX_STYLE_GREEN : ZBX_STYLE_RED)
 					->addClass(ZBX_STYLE_LINK_ALT)
