@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -40,21 +40,14 @@ if ($web_layout_mode == ZBX_LAYOUT_NORMAL) {
 				]
 			]
 		])
-		->addItem((new CList())
-			->setAttribute('role', 'navigation')
-			->setAttribute('aria-label', _x('Hierarchy', 'screen reader'))
-			->addClass(ZBX_STYLE_OBJECT_GROUP)
-			->addClass(ZBX_STYLE_FILTER_BREADCRUMB)
-			->addItem([
-				(new CSpan())->addItem(new CLink(_('All screens'), 'screenconf.php')),
-				'/',
-				(new CSpan())
-					->addClass(ZBX_STYLE_SELECTED)
-					->addItem(
-						new CLink($data['screen']['name'], (new CUrl('screens.php'))
-							->setArgument('elementid', $data['screen']['screenid'])
-					))
-		]));
+		->setNavigation((new CList())->addItem(new CBreadcrumbs([
+			(new CSpan())->addItem(new CLink(_('All screens'), 'screenconf.php')),
+			(new CSpan())
+				->addItem(new CLink($data['screen']['name'],
+					(new CUrl('screens.php'))->setArgument('elementid', $data['screen']['screenid'])
+				))
+				->addClass(ZBX_STYLE_SELECTED)
+		])));
 }
 
 $controls = new CList();
