@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -70,6 +70,7 @@ $availableJScripts = [
 	'jquery.js' => 'vendors/',
 	'jquery-ui.js' => 'vendors/',
 	// classes
+	'component.z-select.js' => '',
 	'class.base-component.js' => '',
 	'class.bbcode.js' => '',
 	'class.calendar.js' => '',
@@ -105,12 +106,20 @@ $availableJScripts = [
 	'class.cviewswitcher.js' => '',
 	'class.pmaster.js' => '',
 	'class.rpc.js' => '',
+	'class.tabfilter.js' => '',
+	'class.tabfilteritem.js' => '',
 	'class.template.js' => '',
 	'init.js' => '',
+	'class.tab-indicators.js' => '',
 	// templates
 	'sysmap.tpl.js' => 'templates/',
 	// page-specific scripts
 	'items.js' => 'pages/',
+	'report2.js' => 'pages/',
+	'report4.js' => 'pages/',
+	'setup.js' => 'pages/',
+	'srv_status.js' => 'pages/',
+	'monitoring.overview.js' => 'pages/',
 	'popup.condition.common.js' => 'pages/',
 	'popup.operation.common.js' => 'pages/'
 ];
@@ -119,6 +128,9 @@ $tranStrings = [
 	'gtlc.js' => [
 		'S_MINUTE_SHORT' => _x('m', 'minute short')
 	],
+	'class.overlay.js' => [
+		'Operation details' => _('Operation details')
+	],
 	'dashboard.grid.js' => [
 		'Edit widget' => _('Edit widget'),
 		'Add widget' => _('Add widget'),
@@ -130,8 +142,6 @@ $tranStrings = [
 		'Edit' => _('Edit'),
 		'Cancel' => _('Cancel'),
 		'Delete' => _('Delete'),
-		'You have unsaved changes.' => _('You have unsaved changes.'),
-		'Are you sure, you want to leave this page?' => _('Are you sure, you want to leave this page?'),
 		'Cannot add widgets in kiosk mode' => _('Cannot add widgets in kiosk mode'),
 		'You do not have permissions to edit dashboard' => _('You do not have permissions to edit dashboard'),
 		'Add a new widget' => _('Add a new widget'),
@@ -319,7 +329,8 @@ $tranStrings = [
 	],
 	'items.js' => [
 		'To set a host interface select a single item type for all items' => _('To set a host interface select a single item type for all items'),
-		'No interface found' => _('No interface found')
+		'No interface found' => _('No interface found'),
+		'Item type does not use interface' => _('Item type does not use interface')
 	],
 	'class.cnavtree.js' => [
 		'Edit' => _('Edit'),
@@ -342,8 +353,13 @@ $tranStrings = [
 	'common.js' => [
 		'Cancel' => _('Cancel')
 	],
+	'component.z-select.js' => [
+		'All' => _('All')
+	],
 	'macrovalue.js' => [
-		'Set new value' => _('Set new value')
+		'Set new value' => _('Set new value'),
+		'path/to/secret:key' => _('path/to/secret:key'),
+		'value' => _('value')
 	]
 ];
 
@@ -354,6 +370,7 @@ if (empty($_GET['files'])) {
 		'jquery.js',
 		'jquery-ui.js',
 		'common.js',
+		'component.z-select.js',
 		'class.base-component.js',
 		'class.cdebug.js',
 		'class.overlaycollection.js',
@@ -377,9 +394,11 @@ if (empty($_GET['files'])) {
 	];
 
 	require_once dirname(__FILE__).'/include/defines.inc.php';
+	require_once dirname(__FILE__).'/include/classes/helpers/CCookieHelper.php';
 
-	if (array_key_exists(ZBX_SESSION_NAME, $_COOKIE)) {
-		$js .= 'window.ZBX_SESSION_NAME = "'.crc32($_COOKIE[ZBX_SESSION_NAME]).'";';
+	if (CCookieHelper::has(ZBX_SESSION_NAME)) {
+		$session = json_decode(base64_decode(CCookieHelper::get(ZBX_SESSION_NAME)), true);
+		$js .= 'window.ZBX_SESSION_NAME = "'.crc32($session['sessionid']).'";';
 		$files[] = 'class.localstorage.js';
 	}
 
