@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of trigger prototypes');
 $page['file'] = 'trigger_prototypes.php';
-$page['scripts'] = ['textareaflexible.js'];
+$page['scripts'] = ['multiselect.js', 'textareaflexible.js', 'class.tab-indicators.js'];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -36,6 +36,7 @@ $fields = [
 	'triggerid' =>								[T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		'(isset({form}) && ({form} == "update"))'],
 	'type' =>									[T_ZBX_INT, O_OPT, null,	IN('0,1'),	null],
 	'description' =>							[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({add}) || isset({update})', _('Name')],
+	'event_name' =>								[T_ZBX_STR, O_OPT, null,	null,		'isset({add}) || isset({update})'],
 	'opdata' =>									[T_ZBX_STR, O_OPT, null,	null,		'isset({add}) || isset({update})'],
 	'expression' =>								[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'isset({add}) || isset({update})', _('Expression')],
 	'recovery_expression' =>					[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,		'(isset({add}) || isset({update})) && isset({recovery_mode}) && {recovery_mode} == '.ZBX_RECOVERY_MODE_RECOVERY_EXPRESSION.'', _('Recovery expression')],
@@ -46,6 +47,7 @@ $fields = [
 	'correlation_mode' =>						[T_ZBX_STR, O_OPT, null,	IN(ZBX_TRIGGER_CORRELATION_NONE.','.ZBX_TRIGGER_CORRELATION_TAG),	null],
 	'correlation_tag' =>						[T_ZBX_STR, O_OPT, null,	null,			'isset({add}) || isset({update})'],
 	'status' =>									[T_ZBX_STR, O_OPT, null,	null,		null],
+	'discover' =>								[T_ZBX_INT, O_OPT, null,	IN([ZBX_PROTOTYPE_DISCOVER, ZBX_PROTOTYPE_NO_DISCOVER]), null],
 	'expression_constructor' =>					[T_ZBX_INT, O_OPT, null,	NOT_EMPTY,	'isset({toggle_expression_constructor})'],
 	'recovery_expression_constructor' =>		[T_ZBX_INT, O_OPT, null,	NOT_EMPTY,		'isset({toggle_recovery_expression_constructor})'],
 	'expr_temp' =>								[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'(isset({add_expression}) || isset({and_expression}) || isset({or_expression}) || isset({replace_expression}))', _('Expression')],
@@ -103,7 +105,7 @@ $fields = [
 	'form' =>									[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form_refresh' =>							[T_ZBX_INT, O_OPT, null,	null,		null],
 	// sort and sortorder
-	'sort' =>									[T_ZBX_STR, O_OPT, P_SYS, IN('"description","priority","status"'),		null],
+	'sort' =>									[T_ZBX_STR, O_OPT, P_SYS, IN('"description","priority","status","discover"'),		null],
 	'sortorder' =>								[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
 ];
 
@@ -201,6 +203,7 @@ if (hasRequest('clone') && hasRequest('triggerid')) {
 elseif (hasRequest('add') || hasRequest('update')) {
 	$dependencies = zbx_toObject(getRequest('dependencies', []), 'triggerid');
 	$description = getRequest('description', '');
+	$event_name = getRequest('event_name', '');
 	$opdata = getRequest('opdata', '');
 	$expression = getRequest('expression', '');
 	$recovery_mode = getRequest('recovery_mode', ZBX_RECOVERY_MODE_EXPRESSION);
@@ -213,10 +216,12 @@ elseif (hasRequest('add') || hasRequest('update')) {
 	$correlation_tag = getRequest('correlation_tag', '');
 	$manual_close = getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED);
 	$status = getRequest('status', TRIGGER_STATUS_ENABLED);
+	$discover = getRequest('discover', DB::getDefault('triggers', 'discover'));
 
 	if (hasRequest('add')) {
 		$trigger_prototype = [
 			'description' => $description,
+			'event_name' => $event_name,
 			'opdata' => $opdata,
 			'expression' => $expression,
 			'recovery_mode' => $recovery_mode,
@@ -227,7 +232,8 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'tags' => $tags,
 			'manual_close' => $manual_close,
 			'dependencies' => $dependencies,
-			'status' => $status
+			'status' => $status,
+			'discover' => $discover
 		];
 		switch ($recovery_mode) {
 			case ZBX_RECOVERY_MODE_RECOVERY_EXPRESSION:
@@ -249,7 +255,8 @@ elseif (hasRequest('add') || hasRequest('update')) {
 	else {
 		$db_trigger_prototypes = API::TriggerPrototype()->get([
 			'output' => ['expression', 'description', 'url', 'status', 'priority', 'comments', 'templateid', 'type',
-				'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag', 'manual_close', 'opdata'
+				'recovery_mode', 'recovery_expression', 'correlation_mode', 'correlation_tag', 'manual_close', 'opdata',
+				'discover', 'event_name'
 			],
 			'selectDependencies' => ['triggerid'],
 			'selectTags' => ['tag', 'value'],
@@ -268,6 +275,9 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			if ($db_trigger_prototype['description'] !== $description) {
 				$trigger_prototype['description'] = $description;
 			}
+			if ($db_trigger_prototype['event_name'] !== $event_name) {
+				$trigger_prototype['event_name'] = $event_name;
+			}
 			if ($db_trigger_prototype['opdata'] !== $opdata) {
 				$trigger_prototype['opdata'] = $opdata;
 			}
@@ -330,6 +340,9 @@ elseif (hasRequest('add') || hasRequest('update')) {
 		if ($db_trigger_prototype['status'] != $status) {
 			$trigger_prototype['status'] = $status;
 		}
+		if ($db_trigger_prototype['discover'] != $discover) {
+			$trigger_prototype['discover'] = $discover;
+		}
 
 		if ($trigger_prototype) {
 			$trigger_prototype['triggerid'] = getRequest('triggerid');
@@ -447,6 +460,10 @@ elseif (hasRequest('action') && getRequest('action') === 'triggerprototype.massu
 						$trigger['manual_close'] = getRequest('manual_close');
 					}
 
+					if (array_key_exists('discover', $visible)) {
+						$trigger['discover'] = getRequest('discover');
+					}
+
 					$triggers_to_update[] = $trigger;
 				}
 			}
@@ -519,8 +536,6 @@ if (hasRequest('action') && getRequest('action') !== 'triggerprototype.massupdat
 	uncheckTableRows(getRequest('parent_discoveryid'), zbx_objectValues($triggerPrototypes, 'triggerid'));
 }
 
-$config = select_config();
-
 /*
  * Display
  */
@@ -530,13 +545,11 @@ if ((getRequest('action') === 'triggerprototype.massupdateform' || hasRequest('m
 	$data['action'] = 'triggerprototype.massupdate';
 	$data['hostid'] = $discoveryRule['hostid'];
 
-	$triggersView = new CView('configuration.trigger.prototype.massupdate', $data);
-	$triggersView->render();
-	$triggersView->show();
+	// Render view.
+	echo (new CView('configuration.trigger.prototype.massupdate', $data))->getOutput();
 }
 elseif (isset($_REQUEST['form'])) {
 	$data = getTriggerFormData([
-		'config' => $config,
 		'form' => getRequest('form'),
 		'form_refresh' => getRequest('form_refresh'),
 		'parent_discoveryid' => getRequest('parent_discoveryid'),
@@ -549,10 +562,12 @@ elseif (isset($_REQUEST['form'])) {
 		'recovery_expr_temp' => getRequest('recovery_expr_temp', ''),
 		'recovery_mode' => getRequest('recovery_mode', ZBX_RECOVERY_MODE_EXPRESSION),
 		'description' => getRequest('description', ''),
+		'event_name' => getRequest('event_name', ''),
 		'opdata' => getRequest('opdata', ''),
 		'type' => getRequest('type', 0),
 		'priority' => getRequest('priority', TRIGGER_SEVERITY_NOT_CLASSIFIED),
 		'status' => getRequest('status', TRIGGER_STATUS_ENABLED),
+		'discover' => getRequest('discover', DB::getDefault('triggers', 'discover')),
 		'comments' => getRequest('comments', ''),
 		'url' => getRequest('url', ''),
 		'expression_constructor' => getRequest('expression_constructor', IM_ESTABLISHED),
@@ -563,16 +578,15 @@ elseif (isset($_REQUEST['form'])) {
 		'hostid' => $discoveryRule['hostid'],
 		'expression_action' => $expression_action,
 		'recovery_expression_action' => $recovery_expression_action,
-		'tags' => $tags,
+		'tags' => array_values($tags),
 		'show_inherited_tags' => getRequest('show_inherited_tags', 0),
 		'correlation_mode' => getRequest('correlation_mode', ZBX_TRIGGER_CORRELATION_NONE),
 		'correlation_tag' => getRequest('correlation_tag', ''),
 		'manual_close' => getRequest('manual_close', ZBX_TRIGGER_MANUAL_CLOSE_NOT_ALLOWED)
 	]);
 
-	$triggersView = new CView('configuration.trigger.prototype.edit', $data);
-	$triggersView->render();
-	$triggersView->show();
+	// render view
+	echo (new CView('configuration.trigger.prototype.edit', $data))->getOutput();
 }
 else {
 	$sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'description'));
@@ -588,7 +602,6 @@ else {
 		'triggers' => [],
 		'sort' => $sortField,
 		'sortorder' => $sortOrder,
-		'config' => $config,
 		'dependencyTriggers' => []
 	];
 
@@ -598,21 +611,32 @@ else {
 		'output' => ['triggerid', $sortField],
 		'discoveryids' => $data['parent_discoveryid'],
 		'sortfield' => $sortField,
-		'limit' => $config['search_limit'] + 1
+		'limit' => CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1
 	];
 	$data['triggers'] = API::TriggerPrototype()->get($options);
 
 	order_result($data['triggers'], $sortField, $sortOrder);
 
-	// paging
-	$url = (new CUrl('trigger_prototypes.php'))
-		->setArgument('parent_discoveryid', $data['parent_discoveryid']);
+	// pager
+	if (hasRequest('page')) {
+		$page_num = getRequest('page');
+	}
+	elseif (isRequestMethod('get') && !hasRequest('cancel')) {
+		$page_num = 1;
+	}
+	else {
+		$page_num = CPagerHelper::loadPage($page['file']);
+	}
 
-	$data['paging'] = getPagingLine($data['triggers'], $sortOrder, $url);
+	CPagerHelper::savePage($page['file'], $page_num);
+
+	$data['paging'] = CPagerHelper::paginate($page_num, $data['triggers'], $sortOrder,
+		(new CUrl('trigger_prototypes.php'))->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+	);
 
 	$data['triggers'] = API::TriggerPrototype()->get([
 		'output' => ['triggerid', 'expression', 'description', 'status', 'priority', 'templateid', 'recovery_mode',
-			'recovery_expression', 'opdata'
+			'recovery_expression', 'opdata', 'discover'
 		],
 		'selectHosts' => ['hostid', 'host'],
 		'selectDependencies' => ['triggerid', 'description'],
@@ -667,11 +691,10 @@ else {
 	}
 
 	$data['parent_templates'] = getTriggerParentTemplates($data['triggers'], ZBX_FLAG_DISCOVERY_PROTOTYPE);
+	$data['allowed_ui_conf_templates'] = CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES);
 
-	// render view
-	$triggersView = new CView('configuration.trigger.prototype.list', $data);
-	$triggersView->render();
-	$triggersView->show();
+	// Render view.
+	echo (new CView('configuration.trigger.prototype.list', $data))->getOutput();
 }
 
 require_once dirname(__FILE__).'/include/page_footer.php';
